@@ -10,84 +10,121 @@
 *************************************************************************/
 #pragma once
 
-#include "Shape.hpp"
 #include "Bound.hpp"
-#include "State.hpp"
 #include "Material.hpp"
+#include "Shape.hpp"
+#include "State.hpp"
 
 #include <lib/base/Math.hpp>
-#include <lib/serialization/Serializable.hpp>
 #include <lib/multimethods/Indexable.hpp>
+#include <lib/serialization/Serializable.hpp>
 
 namespace yade { // Cannot have #include directive inside.
 
 class Scene;
 class Interaction;
 
-class Body: public Serializable{
-	public:
-		// numerical types for storing ids
-		using id_t = int ;
-		// internal structure to hold some interaction of a body; used by InteractionContainer;
-		using MapId2IntrT = std::map<Body::id_t, shared_ptr<Interaction> >;
-		// groupMask type
+class Body : public Serializable {
+public:
+	// numerical types for storing ids
+	using id_t = int;
+	// internal structure to hold some interaction of a body; used by InteractionContainer;
+	using MapId2IntrT = std::map<Body::id_t, shared_ptr<Interaction>>;
+	// groupMask type
 
-		// bits for Body::flags
-		enum { FLAG_BOUNDED=1, FLAG_ASPHERICAL=2, FLAG_SUBDOMAIN=4, FLAG_FLUIDDOMAINBBOX = 8}; /* add powers of 2 as needed */
-		//! symbolic constant for body that doesn't exist.
-		static const Body::id_t ID_NONE;
-		//! get Body pointer given its id. 
-		static const shared_ptr<Body>& byId(Body::id_t _id,Scene* rb=NULL);
-		static const shared_ptr<Body>& byId(Body::id_t _id,shared_ptr<Scene> rb);
-		
-		//! Whether this Body is a Clump.
-		//! @note The following is always true: \code (Body::isClump() XOR Body::isClumpMember() XOR Body::isStandalone()) \endcode
-		bool isClump() const {return clumpId!=ID_NONE && id==clumpId;}
-		//! Whether this Body is member of a Clump.
-		bool isClumpMember() const {return clumpId!=ID_NONE && id!=clumpId;}
-		//! Whether this body is standalone (neither Clump, nor member of a Clump)
-		bool isStandalone() const {return clumpId==ID_NONE;}
+	// bits for Body::flags
+	enum { FLAG_BOUNDED = 1, FLAG_ASPHERICAL = 2, FLAG_SUBDOMAIN = 4, FLAG_FLUIDDOMAINBBOX = 8 }; /* add powers of 2 as needed */
+	//! symbolic constant for body that doesn't exist.
+	static const Body::id_t ID_NONE;
+	//! get Body pointer given its id.
+	static const shared_ptr<Body>& byId(Body::id_t _id, Scene* rb = NULL);
+	static const shared_ptr<Body>& byId(Body::id_t _id, shared_ptr<Scene> rb);
 
-		//! Whether this body has all DOFs blocked
-		// inline accessors
-		// logic: http://stackoverflow.com/questions/47981/how-do-you-set-clear-and-toggle-a-single-bit-in-c
-		bool isDynamic() const { assert(state); return state->blockedDOFs!=State::DOF_ALL; }
-		void setDynamic(bool d){ assert(state); if(d){ state->blockedDOFs=State::DOF_NONE; } else { state->blockedDOFs=State::DOF_ALL; state->vel=state->angVel=Vector3r::Zero(); } }
-		bool isBounded() const {return flags & FLAG_BOUNDED; }
-		void setBounded(bool d){ if(d) flags|=FLAG_BOUNDED; else flags&=~(FLAG_BOUNDED); }
-		bool getIsSubdomain() const {return flags & FLAG_SUBDOMAIN; }
-		void setIsSubdomain(bool d){ if(d) flags|=FLAG_SUBDOMAIN; else flags&=~(FLAG_SUBDOMAIN); }
-		bool isAspherical() const {return flags & FLAG_ASPHERICAL; }
-		void setAspherical(bool d){ if(d) flags|=FLAG_ASPHERICAL; else flags&=~(FLAG_ASPHERICAL); }
-		bool getIsFluidDomainBbox() const {return flags & FLAG_FLUIDDOMAINBBOX;}
-		void setIsFluidDomainBbox(bool d) {if(d) flags|=FLAG_FLUIDDOMAINBBOX; else flags&=~(FLAG_FLUIDDOMAINBBOX);}
-		
-		/*! Hook for clump to update position of members when user-forced reposition and redraw (through GUI) occurs.
+	//! Whether this Body is a Clump.
+	//! @note The following is always true: \code (Body::isClump() XOR Body::isClumpMember() XOR Body::isStandalone()) \endcode
+	bool isClump() const { return clumpId != ID_NONE && id == clumpId; }
+	//! Whether this Body is member of a Clump.
+	bool isClumpMember() const { return clumpId != ID_NONE && id != clumpId; }
+	//! Whether this body is standalone (neither Clump, nor member of a Clump)
+	bool isStandalone() const { return clumpId == ID_NONE; }
+
+	//! Whether this body has all DOFs blocked
+	// inline accessors
+	// logic: http://stackoverflow.com/questions/47981/how-do-you-set-clear-and-toggle-a-single-bit-in-c
+	bool isDynamic() const
+	{
+		assert(state);
+		return state->blockedDOFs != State::DOF_ALL;
+	}
+	void setDynamic(bool d)
+	{
+		assert(state);
+		if (d) {
+			state->blockedDOFs = State::DOF_NONE;
+		} else {
+			state->blockedDOFs = State::DOF_ALL;
+			state->vel = state->angVel = Vector3r::Zero();
+		}
+	}
+	bool isBounded() const { return flags & FLAG_BOUNDED; }
+	void setBounded(bool d)
+	{
+		if (d)
+			flags |= FLAG_BOUNDED;
+		else
+			flags &= ~(FLAG_BOUNDED);
+	}
+	bool getIsSubdomain() const { return flags & FLAG_SUBDOMAIN; }
+	void setIsSubdomain(bool d)
+	{
+		if (d)
+			flags |= FLAG_SUBDOMAIN;
+		else
+			flags &= ~(FLAG_SUBDOMAIN);
+	}
+	bool isAspherical() const { return flags & FLAG_ASPHERICAL; }
+	void setAspherical(bool d)
+	{
+		if (d)
+			flags |= FLAG_ASPHERICAL;
+		else
+			flags &= ~(FLAG_ASPHERICAL);
+	}
+	bool getIsFluidDomainBbox() const { return flags & FLAG_FLUIDDOMAINBBOX; }
+	void setIsFluidDomainBbox(bool d)
+	{
+		if (d)
+			flags |= FLAG_FLUIDDOMAINBBOX;
+		else
+			flags &= ~(FLAG_FLUIDDOMAINBBOX);
+	}
+
+	/*! Hook for clump to update position of members when user-forced reposition and redraw (through GUI) occurs.
 		 * This is useful only in cases when engines that do that in every iteration are not active - i.e. when the simulation is paused.
 		 * (otherwise, GLViewer would depend on Clump and therefore Clump would have to go to core...) */
-		virtual void userForcedDisplacementRedrawHook(){return;}
+	virtual void userForcedDisplacementRedrawHook() { return; }
 
-		boost::python::list py_intrs();
+	boost::python::list py_intrs();
 
-		Body::id_t getId() const {return id;};
-		unsigned int coordNumber() const;  // Number of neighboring particles
+	Body::id_t   getId() const { return id; };
+	unsigned int coordNumber() const; // Number of neighboring particles
 
-		mask_t getGroupMask() const {return groupMask; };
-		bool maskOk(int mask) const;
-		bool maskCompatible(int mask) const;
+	mask_t getGroupMask() const { return groupMask; };
+	bool   maskOk(int mask) const;
+	bool   maskCompatible(int mask) const;
 #ifdef YADE_MASK_ARBITRARY
-		bool maskOk(const mask_t& mask) const;
-		bool maskCompatible(const mask_t& mask) const;
+	bool maskOk(const mask_t& mask) const;
+	bool maskCompatible(const mask_t& mask) const;
 #endif
 
-		// only BodyContainer can set the id of a body
-		friend class BodyContainer;
+	// only BodyContainer can set the id of a body
+	friend class BodyContainer;
 
 	// clang-format off
 	YADE_CLASS_BASE_DOC_ATTRS_CTOR_PY(Body,Serializable,"A particle, basic element of simulation; interacts with other bodies.",
 		((Body::id_t,id,Body::ID_NONE,Attr::readonly,"Unique id of this body."))
 
-		((mask_t,groupMask,1,,"Bitmask for determining interactions."))
+		((mask_t,groupMask,1,,"Bitmask for interaction detection purposes: it is required that two bodies have at least one bit in common in their groupMask for their interaction to be possible from the :yref:`Collider` point of view."))
 		((int,flags,FLAG_BOUNDED,Attr::readonly,"Bits of various body-related flags. *Do not access directly*. In c++, use isDynamic/setDynamic, isBounded/setBounded, isAspherical/setAspherical. In python, use :yref:`Body.dynamic`, :yref:`Body.bounded`, :yref:`Body.aspherical`."))
 #ifdef YADE_MPI
 		((int,subdomain,0,,"the subdomain this body belongs to."))
@@ -97,7 +134,7 @@ class Body: public Serializable{
 		((shared_ptr<Shape>,shape,,,"Geometrical :yref:`Shape`."))
 		((shared_ptr<Bound>,bound,,,":yref:`Bound`, approximating volume for the purposes of collision detection."))
 		((MapId2IntrT,intrs,,Attr::hidden,"Map from otherId to Interaction with otherId, managed by InteractionContainer."))
-		((int,clumpId,Body::ID_NONE,Attr::readonly,"Id of clump this body makes part of; invalid number if not part of clump; see :yref:`Body::isStandalone`, :yref:`Body::isClump`, :yref:`Body::isClumpMember` properties. \n\nNot meant to be modified directly from Python, use :yref:`O.bodies.appendClumped<BodyContainer.appendClumped>` instead."))
+		((Body::id_t,clumpId,Body::ID_NONE,Attr::readonly,"Id of clump this body makes part of; invalid number if not part of clump; see :yref:`Body::isStandalone`, :yref:`Body::isClump`, :yref:`Body::isClumpMember` properties. \n\nNot meant to be modified directly from Python, use :yref:`O.bodies.appendClumped<BodyContainer.appendClumped>` instead."))
 		((long,chain,-1,,"Id of chain to which the body belongs."))
 		((long,iterBorn,-1,Attr::readonly,"Step number at which the body was added to simulation."))
 		((Real,timeBorn,-1,Attr::readonly,"Time at which the body was added to simulation."))
@@ -125,4 +162,3 @@ class Body: public Serializable{
 REGISTER_SERIALIZABLE(Body);
 
 } // namespace yade
-
