@@ -6,10 +6,10 @@
 *  GNU General Public License v2 or later. See file LICENSE for details. *
 *************************************************************************/
 
-#include <lib/base/Logging.hpp>
 #include "SimulationFlow.hpp"
-#include "Scene.hpp"
 #include "Omega.hpp"
+#include "Scene.hpp"
+#include <lib/base/Logging.hpp>
 
 namespace yade { // Cannot have #include directive inside.
 
@@ -17,16 +17,22 @@ CREATE_LOGGER(SimulationFlow);
 
 void SimulationFlow::singleAction()
 {
-	Scene* scene=Omega::instance().getScene().get();
-	if (!scene) throw logic_error("SimulationFlow::singleAction: no Scene object?!");
-	if(scene->subStepping) { 
+	Scene* scene = Omega::instance().getScene().get();
+	if (!scene)
+		throw logic_error("SimulationFlow::singleAction: no Scene object?!");
+	if (scene->subStepping) {
 		LOG_INFO("Sub-stepping disabled when running simulation continuously.");
-		scene->subStepping=false;
+		scene->subStepping = false;
 	}
 	scene->moveToNextTimeStep();
-	if(scene->stopAtIter>0 && scene->iter==scene->stopAtIter) setTerminate(true);
-	if(scene->stopAtTime>0 && scene->time==scene->stopAtTime) setTerminate(true);
+	if (scene->stopAtIter > 0 && scene->iter == scene->stopAtIter) {
+		scene->stopAtIter = -1;
+		setTerminate(true);
+	}
+	if (scene->stopAtTime > 0 && scene->time >= scene->stopAtTime) {
+		setTerminate(true);
+		scene->stopAtTime = -1;
+	}
 };
 
 } // namespace yade
-
