@@ -7,6 +7,7 @@
 #
 # plotting should be set up as usual
 
+from past.builtins import execfile
 import matplotlib
 matplotlib.use('Agg') # headless backend, makes rendering plots after the simulation _much_ faster (and more reliable)
 
@@ -35,3 +36,8 @@ def do(n):
 
 def done():
 	utils.makeVideo(plot.savePlotSequence(O.tmpFilename(),title=title+u'\n\n\nVáclav Šmilauer\neu@doxos.eu\nhttp://www.yade-dem.org'),script+'.mpeg',fps=10,kbps=5000)
+
+# FIXME: it seems that this script works now only with 03-oedometric-test.py, start it with: yade make-simulation-video.py, then type:
+#	do(2)  # simulations[2]=='03-oedometric-test.py'
+#	done()
+
