@@ -16,8 +16,13 @@ logging.basicConfig(level=logging.INFO)
 
 from yade import *
 import yade.qt
+import yade.config
 
-from minieigen import *
+if yade.config.highPrecisionMpmath:
+	import mpmath
+	mpmath.mp.dps=(int(yade.config.highPrecisionDecimalPlaces)+1)
+
+from yade.minieigenHP import *
 
 seqSerializableShowType=True # show type headings in serializable sequences (takes vertical space, but makes the type hyperlinked)
 
@@ -90,7 +95,7 @@ class AttrEditor_Bool(AttrEditor,QFrame):
 		AttrEditor.__init__(self,getter,setter)
 		QFrame.__init__(self,parent)
 		self.checkBox=QCheckBox(self)
-		lay=QVBoxLayout(self); lay.setSpacing(0); lay.addStretch(1); lay.addWidget(self.checkBox); lay.addStretch(1)
+		lay=QVBoxLayout(self); lay.setSpacing(0); lay.setContentsMargins(0,0,0,0); lay.addStretch(1); lay.addWidget(self.checkBox); lay.addStretch(1)
 		self.checkBox.clicked.connect(self.update)
 	def refresh(self): self.checkBox.setChecked(self.getter())
 	def update(self): self.trySetter(self.checkBox.isChecked())
@@ -132,6 +137,22 @@ class AttrEditor_Float(AttrEditor,QLineEdit):
 		try: self.trySetter(float(self.text()))
 		except ValueError: self.refresh()
 
+class AttrEditor_Mpmath(AttrEditor,QLineEdit):
+	def __init__(self,parent,getter,setter):
+		AttrEditor.__init__(self,getter,setter)
+		QLineEdit.__init__(self,parent)
+		self.textEdited.connect(self.isHot)
+		self.selectionChanged.connect(self.isHot)
+		self.editingFinished.connect(self.update)
+	def refresh(self):
+		#if True or not self.hasFocus(): self.home(False)
+		if (not self.hasFocus()):
+			self.setText(str(self.getter()));
+			self.home(False)
+	def update(self):
+		try: self.trySetter(mpmath.mpf(self.text()))
+		except ValueError: self.refresh()
+
 class AttrEditor_Complex(AttrEditor,QLineEdit):
 	def __init__(self,parent,getter,setter):
 		AttrEditor.__init__(self,getter,setter)
@@ -208,7 +229,7 @@ class AttrEditor_Se3(AttrEditor,QFrame):
 	def __init__(self,parent,getter,setter):
 		AttrEditor.__init__(self,getter,setter)
 		QFrame.__init__(self,parent)
-		self.grid=QGridLayout(self); self.grid.setSpacing(0);
+		self.grid=QGridLayout(self); self.grid.setSpacing(0); self.grid.setContentsMargins(0,0,0,0);
 		for row,col in itertools.product(list(range(2)),list(range(5))): # one additional column for vertical line in quaternion
 			if (row,col)==(0,3): continue
 			if (row,col)==(0,4): self.grid.addWidget(QLabel(u'←<i>pos</i> ↙<i>ori</i>',self),row,col); continue
@@ -254,7 +275,7 @@ class AttrEditor_MatrixX(AttrEditor,QFrame):
 		self.setContentsMargins(0,0,0,0)
 		self.first=True
 		val=self.getter()
-		self.grid=QGridLayout(self); self.grid.setSpacing(0);
+		self.grid=QGridLayout(self); self.grid.setSpacing(0); self.grid.setContentsMargins(0,0,0,0);
 		for row,col in itertools.product(list(range(self.rows)),list(range(self.cols))):
 			w=QLineEdit('')
 			self.grid.addWidget(w,row,col);
@@ -337,10 +358,71 @@ class AttrEditor_Matrix3(AttrEditor_MatrixX):
 	def __init__(self,parent,getter,setter):
 		AttrEditor_MatrixX.__init__(self,parent,getter,setter,3,3,lambda r,c:(r,c))
 
+class AttrEditor_QComboBox(AttrEditor,QComboBox):
+	def __init__(self,parent,getter,setter):
+		AttrEditor.__init__(self,getter,setter)
+		QComboBox.__init__(self,parent)
+		self.activated.connect(self.update)
+		for item in self.getter().names: self.addItem(item)
+		try:
+			self.setCurrentText(self.getter().name);
+		except:
+			self.setCurrentIndex(0);
+	def refresh(self):
+		try:
+			self.setCurrentText(self.getter().name);
+		except:
+			self.setCurrentIndex(0);
+	def update(self,v):
+		self.setter(self.currentText())
+		#print("update "+str(v)+ " " +str(self.getter() ))
+		logging.debug('Update %s with %s' % (str(v),str(self.getter())) )
+		pass
+
+class EnumDropDownMenu(object): pass
+
 class Se3FakeType(object): pass
 
-_fundamentalEditorMap={bool:AttrEditor_Bool,str:AttrEditor_Str,int:AttrEditor_Int,float:AttrEditor_Float,complex:AttrEditor_Complex,Quaternion:AttrEditor_Quaternion,Vector2:AttrEditor_Vector2,Vector3:AttrEditor_Vector3,Vector6:AttrEditor_Vector6,Matrix3:AttrEditor_Matrix3,Vector6i:AttrEditor_Vector6i,Vector3i:AttrEditor_Vector3i,Vector2i:AttrEditor_Vector2i,Se3FakeType:AttrEditor_Se3}
-_fundamentalInitValues={bool:True,str:'',int:0,float:0.0,complex:0.0j,Quaternion:Quaternion((0,1,0),0.0),Vector3:Vector3.Zero,Matrix3:Matrix3.Zero,Vector6:Vector6.Zero,Vector6i:Vector6i.Zero,Vector3i:Vector3i.Zero,Vector2i:Vector2i.Zero,Vector2:Vector2.Zero,Se3FakeType:(Vector3.Zero,Quaternion((0,1,0),0.0))}
+_fundamentalEditorMap={
+	 bool:AttrEditor_Bool
+	,str:AttrEditor_Str
+	,int:AttrEditor_Int
+	,float:AttrEditor_Float
+	,complex:AttrEditor_Complex
+	,Quaternion:AttrEditor_Quaternion
+	,Vector2:AttrEditor_Vector2
+	,Vector3:AttrEditor_Vector3
+	,Vector6:AttrEditor_Vector6
+	,Matrix3:AttrEditor_Matrix3
+	,Vector6i:AttrEditor_Vector6i
+	,Vector3i:AttrEditor_Vector3i
+	,Vector2i:AttrEditor_Vector2i
+	,Se3FakeType:AttrEditor_Se3
+	,EnumDropDownMenu:AttrEditor_QComboBox
+}
+
+_fundamentalInitValues={
+	 bool:True
+	,str:''
+	,int:0
+	,float:0.0
+	,complex:0.0j
+	,Quaternion:Quaternion((0,1,0),0.0)
+	,Vector3:Vector3.Zero
+	,Matrix3:Matrix3.Zero
+	,Vector6:Vector6.Zero
+	,Vector6i:Vector6i.Zero
+	,Vector3i:Vector3i.Zero
+	,Vector2i:Vector2i.Zero
+	,Vector2:Vector2.Zero
+	,Se3FakeType:(Vector3.Zero,Quaternion((0,1,0),0.0))
+	,EnumDropDownMenu:0
+}
+
+if yade.config.highPrecisionMpmath:
+	# TODO: handle Complex mpmath.ctx_mp_python.mpc
+	_fundamentalEditorMap[mpmath.ctx_mp_python.mpf]=AttrEditor_Mpmath
+	_fundamentalInitValues[mpmath.ctx_mp_python.mpf]=(mpmath.mpf(0))
 
 class SerQLabel(QLabel):
 	def __init__(self,parent,label,tooltip,path):
@@ -410,6 +492,8 @@ class SerializableEditor(QFrame):
 			'IntrCallback':IntrCallback,'BoundFunctor':BoundFunctor,'IGeomFunctor':IGeomFunctor,'IPhysFunctor':IPhysFunctor,'LawFunctor':LawFunctor,'KinematicEngine':KinematicEngine,
 			'GlShapeFunctor':GlShapeFunctor,'GlStateFunctor':GlStateFunctor,'GlIGeomFunctor':GlIGeomFunctor,'GlIPhysFunctor':GlIPhysFunctor,'GlBoundFunctor':GlBoundFunctor,'GlExtraDrawer':GlExtraDrawer
 		}
+		if yade.config.highPrecisionMpmath:
+			vecMap['mpf']=mpmath.ctx_mp_python.mpf
 		for T,ret in list(vecMap.items()):
 			if vecTest(T,cxxT):
 				logging.debug("Got type %s from cxx type %s"%(repr(ret),cxxT))
@@ -445,6 +529,8 @@ class SerializableEditor(QFrame):
 				#if not t: raise RuntimeError('Unable to guess type of '+str(self.ser)+'.'+attr)
 			# hack for Se3, which is returned as (Vector3,Quaternion) in python
 			elif isinstance(val,tuple) and len(val)==2 and val[0].__class__==Vector3 and val[1].__class__==Quaternion: t=Se3FakeType
+			# recognize a registered py::enum_ from C++
+			elif str(val.__class__.__base__) == "<class 'Boost.Python.enum'>": t = EnumDropDownMenu
 			else: t=val.__class__
 			match=re.search(':yattrflags:`\s*([0-9]+)\s*`',doc) # non-empty attribute
 			flags=int(match.group(1)) if match else 0
