@@ -18,7 +18,7 @@ qglviewer::Vec tuple2vec(py::tuple t)
 		py::extract<Real> e(t[i]);
 		if (!e.check())
 			throw invalid_argument("Element #" + boost::lexical_cast<string>(i) + " is not a number");
-		ret[i] = e();
+		ret[i] = static_cast<qreal>(e());
 	}
 	return ret;
 };
@@ -65,7 +65,7 @@ public:
 	void set_##property(const Vector3r& t)                                                                                                                 \
 	{                                                                                                                                                      \
 		GLV;                                                                                                                                           \
-		setter(qglviewer::Vec(t[0], t[1], t[2]));                                                                                                      \
+		setter(qglviewer::Vec((static_cast<double>(t[0])), (static_cast<double>(t[1])), (static_cast<double>(t[2]))));                                 \
 	}
 	VEC_GET_SET(upVector, glv->camera()->upVector, glv->camera()->setUpVector);
 	VEC_GET_SET(lookAt, glv->camera()->position() + glv->camera()->viewDirection, glv->camera()->lookAt);
@@ -118,7 +118,7 @@ public:
 	void set_##property(Real r)                                                                                                                            \
 	{                                                                                                                                                      \
 		GLV;                                                                                                                                           \
-		setter(r);                                                                                                                                     \
+		setter(static_cast<qreal>(r));                                                                                                                 \
 	}                                                                                                                                                      \
 	Real get_##property()                                                                                                                                  \
 	{                                                                                                                                                      \
@@ -129,25 +129,29 @@ public:
 	void fitAABB(const Vector3r& min, const Vector3r& max)
 	{
 		GLV;
-		glv->camera()->fitBoundingBox(qglviewer::Vec(min[0], min[1], min[2]), qglviewer::Vec(max[0], max[1], max[2]));
+		glv->camera()->fitBoundingBox(
+		        qglviewer::Vec((static_cast<double>(min[0])), (static_cast<double>(min[1])), (static_cast<double>(min[2]))),
+		        qglviewer::Vec((static_cast<double>(max[0])), (static_cast<double>(max[1])), (static_cast<double>(max[2]))));
 	}
 	void fitSphere(const Vector3r& center, Real radius)
 	{
 		GLV;
-		glv->camera()->fitSphere(qglviewer::Vec(center[0], center[1], center[2]), radius);
+		glv->camera()->fitSphere(
+		        qglviewer::Vec((static_cast<double>(center[0])), (static_cast<double>(center[1])), (static_cast<double>(center[2]))),
+		        static_cast<double>(radius));
 	}
 	void showEntireScene()
 	{
 		GLV;
 		glv->camera()->showEntireScene();
 	}
-	void center(bool median)
+	void center(bool median, Real suggestedRadius)
 	{
 		GLV;
 		if (median)
 			glv->centerMedianQuartile();
 		else
-			glv->centerScene();
+			glv->centerScene(suggestedRadius);
 	}
 	Vector2i get_screenSize()
 	{
@@ -216,7 +220,7 @@ public:
 	}
 	void set_bgColor(const Vector3r& c)
 	{
-		QColor cc(int(std::round(255 * c[0])), int(std::round(255 * c[1])), int(std::round(255 * c[2])));
+		QColor cc(int(math::round(255 * c[0])), int(math::round(255 * c[1])), int(math::round(255 * c[2])));
 		GLV;
 		glv->setBackgroundColor(cc);
 	}
@@ -256,7 +260,19 @@ py::list getAllViews()
 	}
 	return ret;
 };
-void centerViews(void) { OpenGLManager::self->centerAllViews(); }
+void centerViews(const Real& suggestedRadius, const Vector3r& gridOrigin, const Vector3r& suggestedCenter, int gridDecimalPlaces)
+{
+	OpenGLManager::self->centerAllViews(suggestedRadius, gridOrigin, suggestedCenter, gridDecimalPlaces);
+}
+py::dict centerValues()
+{
+	py::dict ret;
+	ret["suggestedRadius"]   = OpenGLManager::self->getSuggestedRadius();
+	ret["gridOrigin"]        = OpenGLManager::self->getGridOrigin();
+	ret["suggestedCenter"]   = OpenGLManager::self->getSuggestedCenter();
+	ret["gridDecimalPlaces"] = OpenGLManager::self->getGridDecimalPlaces();
+	return ret;
+}
 
 shared_ptr<OpenGLRenderer> getRenderer() { return OpenGLManager::self->renderer; }
 
@@ -274,8 +290,47 @@ try {
 	glm->emitStartTimer();
 
 	py::def("View", y::createView, "Create a new 3d view.");
-	py::def("center", y::centerViews, "Center all views.");
-	py::def("views", y::getAllViews, "Return list of all open :yref:`yade.qt.GLViewer` objects");
+	py::def("centerValues",
+	        y::centerValues,
+	        ":return: a dictionary with all parameters currently used by ``yade.qt.center(…)``, see :yref:`yade.qt.center<yade.qt._GLViewer.center>` or "
+	        "type ``yade.qt.center?`` for details. Returns zeros if view is closed.");
+	py::def("center",
+	        y::centerViews,
+	        (py::arg("suggestedRadius")   = -1.0,
+	         py::arg("gridOrigin")        = y::Vector3r(0, 0, 0),
+	         py::arg("suggestedCenter")   = y::Vector3r(0, 0, 0),
+	         py::arg("gridDecimalPlaces") = 4),
+	        R"""(
+Center all views.
+
+:param suggestedRadius:   optional parameter, if provided and positive then it will be used instead of automatic radius detection. This parameter affects the (1) size of grid being drawn (2) the Z-clipping distance in OpenGL, it means that if clipping is too large and some of your scene is not being drawn but is "cut" or "sliced" then this parameter needs to be bigger.
+:param gridOrigin:        optional parameter, if provided it will be used as the origin for drawing the grid. Meaning the intersection of all three grids will not be at 0,0,0; but at the provided coordinate rounded to the nearest gridStep.
+:param suggestedCenter:   optional parameter, if provided other than (0,0,0) then it will be used instead of automatic calculation of scene center using bounding boxes. This parameter affects the drawn rotation-center. If you try to rotate the view, and the rotation is around some strange point, then this parameter needs to be changed.
+:param gridDecimalPlaces: default value=4, determines the number of decimal places to be shown on grid labels using stringstream (extra zeros are not shown).
+
+.. note:: You can get the current values of all these four arguments by invoking command: :yref:`yade.qt.centerValues()<yade.qt._GLViewer.centerValues>`
+
+)""");
+	py::def("views", y::getAllViews, R"""(
+
+:return: a list of all open :yref:`yade.qt.GLViewer` objects
+
+If one needs to exactly copy camera position and settings between two different yade sessions, the following commands can be used:
+
+.. code-block:: python
+
+  v=yade.qt.views()[0]                           ## to obtain a handle of currently opened view.
+  v.lookAt, v.viewDir, v.eyePosition, v.upVector ## to print the current camera parameters of the view.
+
+  ## Then copy the output of this command into the second yade session to reposition the camera.
+  v.lookAt, v.viewDir, v.eyePosition, v.upVector = (Vector3(-0.5,1.6,0.47),Vector3(-0.5,0.6,0.4),Vector3(0.015,0.98,-0.012),Vector3(0.84,0.46,0.27))
+  ## Since these parameters depend on each other it might be necessary to execute this command twice.
+
+Also one can call :yref:`yade.qt.centerValues()<yade.qt._GLViewer.centerValues>` to obtain current settings of axis and scene radius (if defaults are not used) and apply them via call to :yref:`yade.qt.center<yade.qt._GLViewer.center>` in the second yade session.
+
+This cumbersome method above may be improved in the future.
+
+)""");
 
 	py::def("Renderer", &y::getRenderer, "Return the active :yref:`OpenGLRenderer` object.");
 
@@ -296,7 +351,7 @@ try {
 	                &pyGLViewer::get_orthographic,
 	                &pyGLViewer::set_orthographic,
 	                "Whether orthographic projection is used; if false, use perspective projection.")
-	        .add_property("screenSize", &pyGLViewer::get_screenSize, &pyGLViewer::set_screenSize, "Size of the viewer's window, in scree pixels")
+	        .add_property("screenSize", &pyGLViewer::get_screenSize, &pyGLViewer::set_screenSize, "Size of the viewer's window, in screen pixels")
 	        .add_property(
 	                "timeDisp",
 	                &pyGLViewer::get_timeDisp,
@@ -315,9 +370,9 @@ try {
 	        .def("showEntireScene", &pyGLViewer::showEntireScene)
 	        .def("center",
 	             &pyGLViewer::center,
-	             (py::arg("median") = true),
+	             (py::arg("median") = true, py::arg("suggestedRadius") = -1.0f),
 	             "Center view. View is centered either so that all bodies fit inside (*median* = False), or so that 75\% of bodies fit inside (*median* = "
-	             "True).")
+	             "True). If radius cannot be determined automatically then suggestedRadius is used.")
 	        .def("saveState",
 	             &pyGLViewer::saveState,
 	             (py::arg("stateFilename") = ".qglviewer.xml"),
@@ -339,4 +394,3 @@ try {
 	boost::python::handle_exception();
 	throw;
 }
-
