@@ -2,23 +2,23 @@
 // 2012 © Kneib Francois <francois.kneib@irstea.fr>
 
 #pragma once
-#include<pkg/common/Dispatching.hpp>
-#include<core/Shape.hpp>
-#include<core/Body.hpp>
-#include<pkg/dem/FrictPhys.hpp>
-#include<pkg/common/Sphere.hpp>
+#include <core/Body.hpp>
+#include <core/Shape.hpp>
+#include <pkg/common/Dispatching.hpp>
+#include <pkg/common/Sphere.hpp>
+#include <pkg/dem/FrictPhys.hpp>
 #ifdef YADE_OPENGL
-	#include<pkg/common/GLDrawFunctors.hpp>
+#include <pkg/common/GLDrawFunctors.hpp>
 #endif
-#include<pkg/dem/CohesiveFrictionalContactLaw.hpp>
-#include<pkg/common/CylScGeom6D.hpp>
+#include <pkg/common/CylScGeom6D.hpp>
+#include <pkg/dem/CohesiveFrictionalContactLaw.hpp>
 
 namespace yade { // Cannot have #include directive inside.
 
-class Cylinder: public Sphere{
-	public:
-// 		Cylinder(Real _radius, Real _length): length(_length) { /*segment=Vector3r(0,0,1)*_length;*/ radius=_radius; createIndex(); }
-		virtual ~Cylinder ();
+class Cylinder : public Sphere {
+public:
+	// 		Cylinder(Real _radius, Real _length): length(_length) { /*segment=Vector3r(0,0,1)*_length;*/ radius=_radius; createIndex(); }
+	virtual ~Cylinder();
 	// clang-format off
 	YADE_CLASS_BASE_DOC_ATTRS_CTOR(Cylinder,Sphere,"Geometry of a cylinder, as Minkowski sum of line and sphere.",
 // 		((Real,radius,NaN,,"Radius [m]"))
@@ -30,17 +30,17 @@ class Cylinder: public Sphere{
 		segment=Vector3r(0,0,1)*length;
 	);
 	// clang-format on
-	REGISTER_CLASS_INDEX(Cylinder,Sphere);
+	REGISTER_CLASS_INDEX(Cylinder, Sphere);
 };
 REGISTER_SERIALIZABLE(Cylinder);
 
-class ChainedCylinder: public Cylinder{
-	public:
-// 		ChainedCylinder(Real _radius, Real _length);/*: Cylinder(_radius,_length){}*/
-		virtual ~ChainedCylinder ();
+class ChainedCylinder : public Cylinder {
+public:
+	// 		ChainedCylinder(Real _radius, Real _length);/*: Cylinder(_radius,_length){}*/
+	virtual ~ChainedCylinder();
 
-		//Keep pointers or copies of connected states?
-// 		ChainedState st1, st2;
+	//Keep pointers or copies of connected states?
+	// 		ChainedState st1, st2;
 
 
 	// clang-format off
@@ -52,35 +52,41 @@ class ChainedCylinder: public Cylinder{
 
 	);
 	// clang-format on
-	REGISTER_CLASS_INDEX(ChainedCylinder,Cylinder);
+	REGISTER_CLASS_INDEX(ChainedCylinder, Cylinder);
 };
 REGISTER_SERIALIZABLE(ChainedCylinder);
 
-class ChainedState: public State{
-	public:
-		static vector<vector<Body::id_t> > chains;
-		static unsigned int currentChain;
-		vector<Body::id_t> barContacts;
-		vector<Body::id_t> nodeContacts;
-// 		shared_ptr<ChainedState> statePrev;
+class ChainedState : public State {
+public:
+	static vector<vector<Body::id_t>> chains;
+	static unsigned int               currentChain;
+	vector<Body::id_t>                barContacts;
+	vector<Body::id_t>                nodeContacts;
+	// 		shared_ptr<ChainedState> statePrev;
 
-		virtual ~ChainedState ();
-		void addToChain(Body::id_t bodyId) {
-			if (chains.size()<=currentChain) chains.resize(currentChain+1);
-			chainNumber=currentChain;
- 			rank=chains[currentChain].size();
- 			chains[currentChain].push_back(bodyId);
-			bId=bodyId;
-// 			if (rank>0) statePrev = Body::byId(chains[chainNumber][rank-1],scene)->state;
-		}
+	virtual ~ChainedState();
+	void addToChain(Body::id_t bodyId)
+	{
+		if (chains.size() <= currentChain)
+			chains.resize(currentChain + 1);
+		chainNumber = currentChain;
+		rank        = chains[currentChain].size();
+		chains[currentChain].push_back(bodyId);
+		bId = bodyId;
+		// 			if (rank>0) statePrev = Body::byId(chains[chainNumber][rank-1],scene)->state;
+	}
 
- 		void postLoad (ChainedState&){
-			if (bId<0) return;//state has not been chained yet
- 			if (chains.size()<=currentChain) chains.resize(currentChain+1);
-			if (chains[currentChain].size()<=rank) chains[currentChain].resize(rank+1);
-			chains[currentChain][rank]=bId;
-// 			if (rank>0) statePrev = Body::byId(chains[chainNumber][rank-1],scene)->state;
-		}
+	void postLoad(ChainedState&)
+	{
+		if (bId < 0)
+			return; //state has not been chained yet
+		if (chains.size() <= currentChain)
+			chains.resize(currentChain + 1);
+		if (chains[currentChain].size() <= rank)
+			chains[currentChain].resize(rank + 1);
+		chains[currentChain][rank] = bId;
+		// 			if (rank>0) statePrev = Body::byId(chains[chainNumber][rank-1],scene)->state;
+	}
 
 	// clang-format off
 	YADE_CLASS_BASE_DOC_ATTRS_INIT_CTOR_PY(ChainedState,State,"State of a chained bodies, containing information on connectivity in order to track contacts jumping over contiguous elements. Chains are 1D lists from which id of chained bodies are retrieved via :yref:`rank<ChainedState::rank>` and :yref:`chainNumber<ChainedState::chainNumber>`.",
@@ -99,30 +105,58 @@ class ChainedState: public State{
 		.def("addToChain",&ChainedState::addToChain,(boost::python::arg("bodyId")),"Add body to current active chain")
 	);
 	// clang-format on
-	REGISTER_CLASS_INDEX(ChainedState,State);
+	REGISTER_CLASS_INDEX(ChainedState, State);
 };
 REGISTER_SERIALIZABLE(ChainedState);
 
 
-class Ig2_Sphere_ChainedCylinder_CylScGeom: public IGeomFunctor{
-	public:
-// 		virtual ~Ig2_Sphere_ChainedCylinder_CylScGeom ();
-		virtual bool go(const shared_ptr<Shape>& cm1, const shared_ptr<Shape>& cm2, const State& state1, const State& state2, const Vector3r& shift2, const bool& force, const shared_ptr<Interaction>& c);
-		virtual bool goReverse(	const shared_ptr<Shape>& cm1, const shared_ptr<Shape>& cm2, const State& state1, const State& state2, const Vector3r& shift2, const bool& force, const shared_ptr<Interaction>& c);
+class Ig2_Sphere_ChainedCylinder_CylScGeom : public IGeomFunctor {
+public:
+	// 		virtual ~Ig2_Sphere_ChainedCylinder_CylScGeom ();
+	virtual bool
+	             go(const shared_ptr<Shape>&       cm1,
+	                const shared_ptr<Shape>&       cm2,
+	                const State&                   state1,
+	                const State&                   state2,
+	                const Vector3r&                shift2,
+	                const bool&                    force,
+	                const shared_ptr<Interaction>& c);
+	virtual bool goReverse(
+	        const shared_ptr<Shape>&       cm1,
+	        const shared_ptr<Shape>&       cm2,
+	        const State&                   state1,
+	        const State&                   state2,
+	        const Vector3r&                shift2,
+	        const bool&                    force,
+	        const shared_ptr<Interaction>& c);
 	// clang-format off
 	YADE_CLASS_BASE_DOC_ATTRS(Ig2_Sphere_ChainedCylinder_CylScGeom,IGeomFunctor,"Create/update a :yref:`ScGeom` instance representing intersection of two :yref:`Spheres<Sphere>`.",
 		((Real,interactionDetectionFactor,1,,"Enlarge both radii by this factor (if >1), to permit creation of distant interactions."))
 	);
 	// clang-format on
-	FUNCTOR2D(Sphere,ChainedCylinder);
-	DEFINE_FUNCTOR_ORDER_2D(Sphere,ChainedCylinder);
+	FUNCTOR2D(Sphere, ChainedCylinder);
+	DEFINE_FUNCTOR_ORDER_2D(Sphere, ChainedCylinder);
 };
 REGISTER_SERIALIZABLE(Ig2_Sphere_ChainedCylinder_CylScGeom);
 
-class Ig2_Sphere_ChainedCylinder_CylScGeom6D: public Ig2_Sphere_ChainedCylinder_CylScGeom {
+class Ig2_Sphere_ChainedCylinder_CylScGeom6D : public Ig2_Sphere_ChainedCylinder_CylScGeom {
 public:
-    virtual bool go(const shared_ptr<Shape>& cm1, const shared_ptr<Shape>& cm2, const State& state1, const State& state2, const Vector3r& shift2, const bool& force, const shared_ptr<Interaction>& c);
-    virtual bool goReverse(	const shared_ptr<Shape>& cm1, const shared_ptr<Shape>& cm2, const State& state1, const State& state2, const Vector3r& shift2, const bool& force, const shared_ptr<Interaction>& c);
+	virtual bool
+	             go(const shared_ptr<Shape>&       cm1,
+	                const shared_ptr<Shape>&       cm2,
+	                const State&                   state1,
+	                const State&                   state2,
+	                const Vector3r&                shift2,
+	                const bool&                    force,
+	                const shared_ptr<Interaction>& c);
+	virtual bool goReverse(
+	        const shared_ptr<Shape>&       cm1,
+	        const shared_ptr<Shape>&       cm2,
+	        const State&                   state1,
+	        const State&                   state2,
+	        const Vector3r&                shift2,
+	        const bool&                    force,
+	        const shared_ptr<Interaction>& c);
 
 	// clang-format off
     YADE_CLASS_BASE_DOC_ATTRS(Ig2_Sphere_ChainedCylinder_CylScGeom6D,Ig2_Sphere_ChainedCylinder_CylScGeom,"Create/update a :yref:`ScGeom6D` instance representing the geometry of a contact point between two :yref:`Spheres<Sphere>`, including relative rotations.",
@@ -131,40 +165,55 @@ public:
                                ))
                              );
 	// clang-format on
-    FUNCTOR2D(Sphere,ChainedCylinder);
-    // needed for the dispatcher, even if it is symmetric
-    DEFINE_FUNCTOR_ORDER_2D(Sphere,ChainedCylinder);
+	FUNCTOR2D(Sphere, ChainedCylinder);
+	// needed for the dispatcher, even if it is symmetric
+	DEFINE_FUNCTOR_ORDER_2D(Sphere, ChainedCylinder);
 };
 REGISTER_SERIALIZABLE(Ig2_Sphere_ChainedCylinder_CylScGeom6D);
 
-class Ig2_ChainedCylinder_ChainedCylinder_ScGeom6D: public IGeomFunctor{
-	public:
-// 		virtual ~Ig2_ChainedCylinder_ChainedCylinder_ScGeom6D ()  {};
-		virtual bool go(const shared_ptr<Shape>& cm1, const shared_ptr<Shape>& cm2, const State& state1, const State& state2, const Vector3r& shift2, const bool& force, const shared_ptr<Interaction>& c);
-		virtual bool goReverse(	const shared_ptr<Shape>& cm1, const shared_ptr<Shape>& cm2, const State& state1, const State& state2, const Vector3r& shift2, const bool& force, const shared_ptr<Interaction>& c);
+class Ig2_ChainedCylinder_ChainedCylinder_ScGeom6D : public IGeomFunctor {
+public:
+	// 		virtual ~Ig2_ChainedCylinder_ChainedCylinder_ScGeom6D ()  {};
+	virtual bool
+	             go(const shared_ptr<Shape>&       cm1,
+	                const shared_ptr<Shape>&       cm2,
+	                const State&                   state1,
+	                const State&                   state2,
+	                const Vector3r&                shift2,
+	                const bool&                    force,
+	                const shared_ptr<Interaction>& c);
+	virtual bool goReverse(
+	        const shared_ptr<Shape>&       cm1,
+	        const shared_ptr<Shape>&       cm2,
+	        const State&                   state1,
+	        const State&                   state2,
+	        const Vector3r&                shift2,
+	        const bool&                    force,
+	        const shared_ptr<Interaction>& c);
 	// clang-format off
 	YADE_CLASS_BASE_DOC_ATTRS(Ig2_ChainedCylinder_ChainedCylinder_ScGeom6D,IGeomFunctor,"Create/update a :yref:`ScGeom` instance representing connexion between :yref:`chained cylinders<ChainedCylinder>`.",
 		((Real,interactionDetectionFactor,1,,"Enlarge both radii by this factor (if >1), to permit creation of distant interactions."))
 		((bool,halfLengthContacts,true,,"If True, Cylinders nodes interact like spheres of radius 0.5*length, else one node has size length while the other has size 0. The difference is mainly the locus of rotation definition."))
 	);
 	// clang-format on
-	FUNCTOR2D(ChainedCylinder,ChainedCylinder);
+	FUNCTOR2D(ChainedCylinder, ChainedCylinder);
 	// needed for the dispatcher, even if it is symmetric
-	DEFINE_FUNCTOR_ORDER_2D(ChainedCylinder,ChainedCylinder);
+	DEFINE_FUNCTOR_ORDER_2D(ChainedCylinder, ChainedCylinder);
 };
 REGISTER_SERIALIZABLE(Ig2_ChainedCylinder_ChainedCylinder_ScGeom6D);
 
 
 #ifdef YADE_OPENGL
-class Gl1_Cylinder : public GlShapeFunctor{
-	private:
-		static int glCylinderList;
-		void subdivideTriangle(Vector3r& v1,Vector3r& v2,Vector3r& v3, int depth);
-		void drawCylinder(bool wire, Real radius, Real length, const Quaternionr& shift=Quaternionr::Identity()) const;
-		void initGlLists(void);
-	public:
-		virtual void go(const shared_ptr<Shape>&, const shared_ptr<State>&,bool,const GLViewInfo&);
-		void out( Quaternionr q );
+class Gl1_Cylinder : public GlShapeFunctor {
+private:
+	static int glCylinderList;
+	void       subdivideTriangle(Vector3r& v1, Vector3r& v2, Vector3r& v3, int depth);
+	void       drawCylinder(bool wire, Real radius, Real length, const Quaternionr& shift = Quaternionr::Identity()) const;
+	void       initGlLists(void);
+
+public:
+	virtual void go(const shared_ptr<Shape>&, const shared_ptr<State>&, bool, const GLViewInfo&);
+	void         out(Quaternionr q);
 	// clang-format off
 	YADE_CLASS_BASE_DOC_STATICATTRS(Gl1_Cylinder,GlShapeFunctor,"Renders :yref:`Cylinder` object",
 		((bool,wire,false,,"Only show wireframe (controlled by ``glutSlices`` and ``glutStacks``."))
@@ -178,9 +227,9 @@ class Gl1_Cylinder : public GlShapeFunctor{
 };
 
 //!This doesn't work : the 1D dispatcher will pick Gl1_Cylinder to display ChainedCylinders, workaround : add shift to cylinders (should be a variable of chained cylinders only).
-class Gl1_ChainedCylinder : public Gl1_Cylinder{
-	public:
-		virtual void go(const shared_ptr<Shape>&, const shared_ptr<State>& state, bool,const GLViewInfo&);
+class Gl1_ChainedCylinder : public Gl1_Cylinder {
+public:
+	virtual void go(const shared_ptr<Shape>&, const shared_ptr<State>& state, bool, const GLViewInfo&);
 	// clang-format off
 	YADE_CLASS_BASE_DOC(Gl1_ChainedCylinder,Gl1_Cylinder,"Renders :yref:`ChainedCylinder` object including a shift for compensating flexion."
 	);
@@ -212,10 +261,9 @@ class Gl1_ChainedCylinder : public GlShapeFunctor{
 #endif
 
 
-class Bo1_Cylinder_Aabb : public BoundFunctor
-{
-	public :
-		void go(const shared_ptr<Shape>& cm, shared_ptr<Bound>& bv, const Se3r&, const Body*);
+class Bo1_Cylinder_Aabb : public BoundFunctor {
+public:
+	void go(const shared_ptr<Shape>& cm, shared_ptr<Bound>& bv, const Se3r&, const Body*);
 	FUNCTOR1D(Cylinder);
 	// clang-format off
 	YADE_CLASS_BASE_DOC_ATTRS(Bo1_Cylinder_Aabb,BoundFunctor,"Functor creating :yref:`Aabb` from :yref:`Cylinder`.",
@@ -225,10 +273,9 @@ class Bo1_Cylinder_Aabb : public BoundFunctor
 };
 REGISTER_SERIALIZABLE(Bo1_Cylinder_Aabb);
 
-class Bo1_ChainedCylinder_Aabb : public BoundFunctor
-{
-	public :
-		void go(const shared_ptr<Shape>& cm, shared_ptr<Bound>& bv, const Se3r&, const Body*);
+class Bo1_ChainedCylinder_Aabb : public BoundFunctor {
+public:
+	void go(const shared_ptr<Shape>& cm, shared_ptr<Bound>& bv, const Se3r&, const Body*);
 	FUNCTOR1D(ChainedCylinder);
 	// clang-format off
 	YADE_CLASS_BASE_DOC_ATTRS(Bo1_ChainedCylinder_Aabb,BoundFunctor,"Functor creating :yref:`Aabb` from :yref:`ChainedCylinder`.",
@@ -239,13 +286,13 @@ class Bo1_ChainedCylinder_Aabb : public BoundFunctor
 REGISTER_SERIALIZABLE(Bo1_ChainedCylinder_Aabb);
 
 
-class Law2_CylScGeom_FrictPhys_CundallStrack: public LawFunctor{
-	public:
-		//OpenMPAccumulator<Real> plasticDissipation;
-		virtual bool go(shared_ptr<IGeom>& _geom, shared_ptr<IPhys>& _phys, Interaction* I);
-		//Real elasticEnergy ();
-		//Real getPlasticDissipation();
-		//void initPlasticDissipation(Real initVal=0);
+class Law2_CylScGeom_FrictPhys_CundallStrack : public LawFunctor {
+public:
+	//OpenMPAccumulator<Real> plasticDissipation;
+	virtual bool go(shared_ptr<IGeom>& _geom, shared_ptr<IPhys>& _phys, Interaction* I);
+	//Real elasticEnergy ();
+	//Real getPlasticDissipation();
+	//void initPlasticDissipation(Real initVal=0);
 	// clang-format off
 		YADE_CLASS_BASE_DOC_ATTRS_CTOR_PY(Law2_CylScGeom_FrictPhys_CundallStrack,LawFunctor,"Law for linear compression, and Mohr-Coulomb plasticity surface without cohesion.\nThis law implements the classical linear elastic-plastic law from [CundallStrack1979]_ (see also [Pfc3dManual30]_). The normal force is (with the convention of positive tensile forces) $F_n=\\min(k_n u_n, 0)$. The shear force is $F_s=k_s u_s$, the plasticity condition defines the maximum value of the shear force : $F_s^{\\max}=F_n\\tan(\\phi)$, with $\\phi$ the friction angle.\n\n.. note::\n This law uses :yref:`ScGeom`.\n\n.. note::\n This law is well tested in the context of triaxial simulation, and has been used for a number of published results (see e.g. [Scholtes2009b]_ and other papers from the same authors). It is generalised by :yref:`Law2_ScGeom6D_CohFrictPhys_CohesionMoment`, which adds cohesion and moments at contact.",
 		((bool,neverErase,false,,"Keep interactions even if particles go away from each other (only in case another constitutive law is in the scene, e.g. :yref:`Law2_ScGeom_CapillaryPhys_Capillarity`)"))
@@ -258,17 +305,17 @@ class Law2_CylScGeom_FrictPhys_CundallStrack: public LawFunctor{
 		//.def("initPlasticDissipation",&Law2_ScGeom_FrictPhys_CundallStrack::initPlasticDissipation,"Initialize cummulated plastic dissipation to a value (0 by default).")
 	);
 	// clang-format on
-	FUNCTOR2D(CylScGeom,FrictPhys);
+	FUNCTOR2D(CylScGeom, FrictPhys);
 };
 REGISTER_SERIALIZABLE(Law2_CylScGeom_FrictPhys_CundallStrack);
 
-class Law2_CylScGeom6D_CohFrictPhys_CohesionMoment: public LawFunctor {
+class Law2_CylScGeom6D_CohFrictPhys_CohesionMoment : public LawFunctor {
 public:
-    //OpenMPAccumulator<Real> plasticDissipation;
-    virtual bool go(shared_ptr<IGeom>& _geom, shared_ptr<IPhys>& _phys, Interaction* I);
-    //Real elasticEnergy ();
-    //Real getPlasticDissipation();
-    //void initPlasticDissipation(Real initVal=0);
+	//OpenMPAccumulator<Real> plasticDissipation;
+	virtual bool go(shared_ptr<IGeom>& _geom, shared_ptr<IPhys>& _phys, Interaction* I);
+	//Real elasticEnergy ();
+	//Real getPlasticDissipation();
+	//void initPlasticDissipation(Real initVal=0);
 	// clang-format off
     YADE_CLASS_BASE_DOC_ATTRS_CTOR_PY(Law2_CylScGeom6D_CohFrictPhys_CohesionMoment,LawFunctor,"This law generalises :yref:`Law2_CylScGeom_FrictPhys_CundallStrack` by adding cohesion and moments at contact.",
                                       ((bool,neverErase,false,,"Keep interactions even if particles go away from each other (only in case another constitutive law is in the scene, e.g. :yref:`Law2_ScGeom_CapillaryPhys_Capillarity`)"))
@@ -283,17 +330,16 @@ public:
                                       ,,
                                      );
 	// clang-format on
-    FUNCTOR2D(CylScGeom6D,CohFrictPhys);
-    DECLARE_LOGGER;
-
+	FUNCTOR2D(CylScGeom6D, CohFrictPhys);
+	DECLARE_LOGGER;
 };
 REGISTER_SERIALIZABLE(Law2_CylScGeom6D_CohFrictPhys_CohesionMoment);
 
 
-class Law2_ChCylGeom6D_CohFrictPhys_CohesionMoment: public LawFunctor {
+class Law2_ChCylGeom6D_CohFrictPhys_CohesionMoment : public LawFunctor {
 public:
-    //OpenMPAccumulator<Real> plasticDissipation;
-    virtual bool go(shared_ptr<IGeom>& _geom, shared_ptr<IPhys>& _phys, Interaction* I);
+	//OpenMPAccumulator<Real> plasticDissipation;
+	virtual bool go(shared_ptr<IGeom>& _geom, shared_ptr<IPhys>& _phys, Interaction* I);
 	// clang-format off
     YADE_CLASS_BASE_DOC_ATTRS_CTOR_PY(Law2_ChCylGeom6D_CohFrictPhys_CohesionMoment,LawFunctor,"Law for linear compression, and Mohr-Coulomb plasticity surface without cohesion.\nThis law implements the classical linear elastic-plastic law from [CundallStrack1979]_ (see also [Pfc3dManual30]_). The normal force is (with the convention of positive tensile forces) $F_n=\\min(k_n u_n, 0)$. The shear force is $F_s=k_s u_s$, the plasticity condition defines the maximum value of the shear force : $F_s^{\\max}=F_n\\tan(\\phi)$, with $\\phi$ the friction angle.\n\n.. note::\n This law is well tested in the context of triaxial simulation, and has been used for a number of published results (see e.g. [Scholtes2009b]_ and other papers from the same authors). It is generalised by :yref:`Law2_ScGeom6D_CohFrictPhys_CohesionMoment`, which adds cohesion and moments at contact.",
                                       ((bool,neverErase,false,,"Keep interactions even if particles go away from each other (only in case another constitutive law is in the scene, e.g. :yref:`Law2_ScGeom_CapillaryPhys_Capillarity`)"))
@@ -308,9 +354,8 @@ public:
                                       ,,
                                      );
 	// clang-format on
-    FUNCTOR2D(ChCylGeom6D,CohFrictPhys);
-    DECLARE_LOGGER;
-
+	FUNCTOR2D(ChCylGeom6D, CohFrictPhys);
+	DECLARE_LOGGER;
 };
 REGISTER_SERIALIZABLE(Law2_ChCylGeom6D_CohFrictPhys_CohesionMoment);
 
@@ -321,11 +366,11 @@ REGISTER_SERIALIZABLE(Law2_ChCylGeom6D_CohFrictPhys_CohesionMoment);
 // 	public :
 // 		void go(const shared_ptr<Shape>& cm, shared_ptr<Bound>& bv, const Se3r&, const Body*);
 // 	FUNCTOR1D(ChainedCylinder);
-	// clang-format off
+// clang-format off
 // 	YADE_CLASS_BASE_DOC_ATTRS(Bo1_ChainedCylinder_Aabb,Bo1_Cylinder_Aabb,"Functor creating :yref:`Aabb` from :yref:`Cylinder`.",
 // 		((Real,aabbEnlargeFactor,((void)"deactivated",-1),,"Relative enlargement of the bounding box; deactivated if negative.\n\n.. note::\n\tThis attribute is used to create distant interaction, but is only meaningful with an :yref:`IGeomFunctor` which will not simply discard such interactions: :yref:`Ig2_Cylinder_Cylinder_Dem3DofGeom::distFactor` / :yref:`Ig2_Cylinder_Cylinder_ScGeom::interactionDetectionFactor` should have the same value as :yref:`aabbEnlargeFactor<Bo1_Cylinder_Aabb::aabbEnlargeFactor>`."))
 // 	);
-	// clang-format on
+// clang-format on
 // };
 
 #ifdef YADE_OPENGL
@@ -334,4 +379,3 @@ REGISTER_SERIALIZABLE(Gl1_ChainedCylinder);
 #endif
 
 } // namespace yade
-
