@@ -260,11 +260,11 @@ Real ImpFunc::FunctionValue(Real x[3])
 	vector<Real> p;
 	Real         pSum2 = 0.0;
 	if (!clump) {
-		Eigen::Vector3d xori(x[0], x[1], x[2]);
-		Eigen::Vector3d xlocal = rotationMatrix * xori;
-		xlocal[0]              = rotationMatrix(0, 0) * x[0] + rotationMatrix(0, 1) * x[1] + rotationMatrix(0, 2) * x[2];
-		xlocal[1]              = rotationMatrix(1, 0) * x[0] + rotationMatrix(1, 1) * x[1] + rotationMatrix(1, 2) * x[2];
-		xlocal[2]              = rotationMatrix(2, 0) * x[0] + rotationMatrix(2, 1) * x[1] + rotationMatrix(2, 2) * x[2];
+		Vector3r xori(x[0], x[1], x[2]);
+		Vector3r xlocal = rotationMatrix * xori;
+		xlocal[0]       = rotationMatrix(0, 0) * x[0] + rotationMatrix(0, 1) * x[1] + rotationMatrix(0, 2) * x[2];
+		xlocal[1]       = rotationMatrix(1, 0) * x[0] + rotationMatrix(1, 1) * x[1] + rotationMatrix(1, 2) * x[2];
+		xlocal[2]       = rotationMatrix(2, 0) * x[0] + rotationMatrix(2, 1) * x[1] + rotationMatrix(2, 2) * x[2];
 		//std::cout<<"rotationMatrix: "<<endl<<rotationMatrix<<endl;
 		//x[0]=xlocal[0]; x[1]=xlocal[1]; x[2]=xlocal[2];
 
@@ -280,9 +280,9 @@ Real ImpFunc::FunctionValue(Real x[3])
 		Real f      = (1.0 - k) * (pSum2 / pow(r, 2) - 1.0) + k * (sphere / pow(R, 2) - 1.0);
 		return f;
 	} else {
-		Eigen::Vector3d xori(x[0], x[1], x[2]);
-		Eigen::Vector3d clumpMemberCentre(clumpMemberCentreX, clumpMemberCentreY, clumpMemberCentreZ);
-		Eigen::Vector3d xlocal = xori - clumpMemberCentre;
+		Vector3r xori(x[0], x[1], x[2]);
+		Vector3r clumpMemberCentre(clumpMemberCentreX, clumpMemberCentreY, clumpMemberCentreZ);
+		Vector3r xlocal = xori - clumpMemberCentre;
 		//xlocal[0] = rotationMatrix[0]*x[0] + rotationMatrix[3]*x[1] + rotationMatrix[6]*x[2];
 		//xlocal[1] = rotationMatrix[1]*x[0] + rotationMatrix[4]*x[1] + rotationMatrix[7]*x[2];
 		//xlocal[2] = rotationMatrix[2]*x[0] + rotationMatrix[5]*x[1] + rotationMatrix[8]*x[2];
@@ -310,58 +310,58 @@ void PotentialParticleVTKRecorder::action()
 {
 	if (fileName.size() == 0)
 		return;
-	vtkSmartPointer<vtkPoints>         pbPos          = vtkSmartPointer<vtkPoints>::New();
-	vtkSmartPointer<vtkAppendPolyData> appendFilter   = vtkSmartPointer<vtkAppendPolyData>::New();
-	vtkSmartPointer<vtkAppendPolyData> appendFilterID = vtkSmartPointer<vtkAppendPolyData>::New();
-	//vtkSmartPointer<vtkTransformPolyDataFilter> transformFilter = vtkSmartPointer<vtkTransformPolyDataFilter>::New();
-	//vtkSmartPointer<vtkTransform> transform = vtkSmartPointer<vtkTransform>::New();
+	auto pbPos          = vtkSmartPointer<vtkPointsReal>::New();
+	auto appendFilter   = vtkSmartPointer<vtkAppendPolyData>::New();
+	auto appendFilterID = vtkSmartPointer<vtkAppendPolyData>::New();
+	//auto transformFilter = vtkSmartPointer<vtkTransformPolyDataFilter>::New();
+	//auto transform = vtkSmartPointer<vtkTransform>::New();
 
 	// interactions ###############################################
-	vtkSmartPointer<vtkPoints>     intrBodyPos = vtkSmartPointer<vtkPoints>::New();
-	vtkSmartPointer<vtkCellArray>  intrCells   = vtkSmartPointer<vtkCellArray>::New();
-	vtkSmartPointer<vtkFloatArray> intrForceN  = vtkSmartPointer<vtkFloatArray>::New();
+	auto intrBodyPos = vtkSmartPointer<vtkPoints>::New();
+	auto intrCells   = vtkSmartPointer<vtkCellArray>::New();
+	auto intrForceN  = vtkSmartPointer<vtkFloatArray>::New();
 	intrForceN->SetNumberOfComponents(3);
 	intrForceN->SetName("forceN");
-	vtkSmartPointer<vtkFloatArray> intrAbsForceT = vtkSmartPointer<vtkFloatArray>::New();
+	auto intrAbsForceT = vtkSmartPointer<vtkFloatArray>::New();
 	intrAbsForceT->SetNumberOfComponents(1);
 	intrAbsForceT->SetName("absForceT");
 	// interactions ###############################################
 
 	// interaction contact point ###############################################
-	vtkSmartPointer<vtkPoints>     pbContactPoint = vtkSmartPointer<vtkPoints>::New();
-	vtkSmartPointer<vtkCellArray>  pbCellsContact = vtkSmartPointer<vtkCellArray>::New();
-	vtkSmartPointer<vtkFloatArray> pbNormalForce  = vtkSmartPointer<vtkFloatArray>::New();
+	auto pbContactPoint = vtkSmartPointer<vtkPointsReal>::New();
+	auto pbCellsContact = vtkSmartPointer<vtkCellArray>::New();
+	auto pbNormalForce  = vtkSmartPointer<vtkFloatArray>::New();
 	pbNormalForce->SetNumberOfComponents(3);
 	pbNormalForce->SetName("normalForce"); //Linear velocity in Vector3 form
-	vtkSmartPointer<vtkFloatArray> pbShearForce = vtkSmartPointer<vtkFloatArray>::New();
+	auto pbShearForce = vtkSmartPointer<vtkFloatArray>::New();
 	pbShearForce->SetNumberOfComponents(3);
 	pbShearForce->SetName("shearForce"); //Angular velocity in Vector3 form
 	// interactions contact point###############################################
 
 
 	// velocity ###################################################
-	vtkSmartPointer<vtkCellArray>  pbCells     = vtkSmartPointer<vtkCellArray>::New();
-	vtkSmartPointer<vtkFloatArray> pbLinVelVec = vtkSmartPointer<vtkFloatArray>::New();
+	auto pbCells     = vtkSmartPointer<vtkCellArray>::New();
+	auto pbLinVelVec = vtkSmartPointer<vtkFloatArray>::New();
 	pbLinVelVec->SetNumberOfComponents(3);
 	pbLinVelVec->SetName("linVelVec"); //Linear velocity in Vector3 form
 
-	vtkSmartPointer<vtkFloatArray> pbLinVelLen = vtkSmartPointer<vtkFloatArray>::New();
+	auto pbLinVelLen = vtkSmartPointer<vtkFloatArray>::New();
 	pbLinVelLen->SetNumberOfComponents(1);
 	pbLinVelLen->SetName("linVelLen"); //Length (magnitude) of linear velocity
 
-	vtkSmartPointer<vtkFloatArray> pbAngVelVec = vtkSmartPointer<vtkFloatArray>::New();
+	auto pbAngVelVec = vtkSmartPointer<vtkFloatArray>::New();
 	pbAngVelVec->SetNumberOfComponents(3);
 	pbAngVelVec->SetName("angVelVec"); //Angular velocity in Vector3 form
 
-	vtkSmartPointer<vtkFloatArray> pbAngVelLen = vtkSmartPointer<vtkFloatArray>::New();
+	auto pbAngVelLen = vtkSmartPointer<vtkFloatArray>::New();
 	pbAngVelLen->SetNumberOfComponents(1);
 	pbAngVelLen->SetName("angVelLen"); //Length (magnitude) of angular velocity
 	// velocity ####################################################
 
 	// bodyId ##############################################################
-	vtkSmartPointer<vtkPoints>    pbPosID   = vtkSmartPointer<vtkPoints>::New();
-	vtkSmartPointer<vtkCellArray> pbIdCells = vtkSmartPointer<vtkCellArray>::New();
-	vtkSmartPointer<vtkIntArray>  blockId   = vtkSmartPointer<vtkIntArray>::New();
+	auto pbPosID   = vtkSmartPointer<vtkPointsReal>::New();
+	auto pbIdCells = vtkSmartPointer<vtkCellArray>::New();
+	auto blockId   = vtkSmartPointer<vtkIntArray>::New();
 	blockId->SetNumberOfComponents(1);
 	blockId->SetName("id");
 	// bodyId ##############################################################
@@ -385,21 +385,21 @@ void PotentialParticleVTKRecorder::action()
 			blockId->InsertNextValue(b->getId());
 			vtkIdType pid[1];
 			Vector3r  pos(b->state->pos);
-			pid[0] = pbPosID->InsertNextPoint(pos[0], pos[1], pos[2]);
+			pid[0] = pbPosID->InsertNextPoint(pos);
 			pbIdCells->InsertNextCell(1, pid);
 
 			countID++;
 		}
 		//vtkSmartPointer<ImpFunc> function = ImpFunc::New();
-		function->a                  = pb->a;
-		function->b                  = pb->b;
-		function->c                  = pb->c;
-		function->d                  = pb->d;
-		function->R                  = pb->R;
-		function->r                  = pb->r;
-		function->k                  = pb->k;
-		Eigen::Matrix3d directionCos = b->state->ori.conjugate().toRotationMatrix();
-		int             count        = 0;
+		function->a           = pb->a;
+		function->b           = pb->b;
+		function->c           = pb->c;
+		function->d           = pb->d;
+		function->R           = pb->R;
+		function->r           = pb->r;
+		function->k           = pb->k;
+		Matrix3r directionCos = b->state->ori.conjugate().toRotationMatrix();
+		int      count        = 0;
 		for (int i = 0; i < 3; i++) {
 			for (int j = 0; j < 3; j++) {
 				//function->rotationMatrix[count] = directionCos(j,i);
@@ -409,7 +409,7 @@ void PotentialParticleVTKRecorder::action()
 		}
 
 
-		vtkSmartPointer<vtkSampleFunction> sample = vtkSampleFunction::New();
+		auto sample = vtkSmartPointer<vtkSampleFunctionReal>::New();
 		sample->SetImplicitFunction(function);
 
 		Real xmin = -std::max(pb->minAabb.x(), pb->maxAabb.x());
@@ -429,7 +429,7 @@ void PotentialParticleVTKRecorder::action()
 			}
 		}
 
-		sample->SetModelBounds(xmin, xmax, ymin, ymax, zmin, zmax);
+		sample->SetModelBounds(Vector3r(xmin, ymin, zmin), Vector3r(xmax, ymax, zmax));
 		//sample->SetModelBounds(pb->minAabb.x(), pb->maxAabb.x(), pb->minAabb.y(), pb->maxAabb.y(), pb->minAabb.z(), pb->maxAabb.z());
 		int sampleXno = sampleX;
 		int sampleYno = sampleY;
@@ -455,22 +455,17 @@ void PotentialParticleVTKRecorder::action()
 		sample->SetSampleDimensions(sampleXno, sampleYno, sampleZno);
 		sample->ComputeNormalsOff();
 		//sample->Update();
-		vtkSmartPointer<vtkContourFilter> contours = vtkContourFilter::New();
-		//#ifdef YADE_VTK6
+		auto contours = vtkSmartPointer<vtkContourFilter>::New();
 		contours->SetInputConnection(sample->GetOutputPort());
-		// #else
-		//		  contours->SetInput(sample->GetOutput());
-		//		#endif
-
 
 		contours->SetNumberOfContours(1);
 		contours->SetValue(0, 0.0);
-		vtkSmartPointer<vtkPolyData> polydata = vtkSmartPointer<vtkPolyData>::New();
+		auto polydata = vtkSmartPointer<vtkPolyData>::New();
 		contours->Update();
 		polydata->DeepCopy(contours->GetOutput());
 		//polydata->Update();
 
-		vtkSmartPointer<vtkUnsignedCharArray> pbColors = vtkSmartPointer<vtkUnsignedCharArray>::New();
+		auto pbColors = vtkSmartPointer<vtkUnsignedCharArray>::New();
 		pbColors->SetName("pbColors");
 		pbColors->SetNumberOfComponents(3);
 		Vector3r color = pb->color; //Vector3r(0,100,0);
@@ -494,18 +489,14 @@ void PotentialParticleVTKRecorder::action()
 		orientation.normalize();
 		AngleAxisr aa(orientation);
 		//Vector3r axis = aa.axis();
-		vtkSmartPointer<vtkTransformPolyDataFilter> transformFilter = vtkSmartPointer<vtkTransformPolyDataFilter>::New();
-		// #ifdef YADE_VTK6
+		auto transformFilter = vtkSmartPointer<vtkTransformPolyDataFilter>::New();
 		transformFilter->SetInputData(polydata);
-		//#else
-		// transformFilter->SetInput( polydata );
-		//#endif
-		vtkSmartPointer<vtkTransform> transform = vtkSmartPointer<vtkTransform>::New();
+		auto transform = vtkSmartPointer<vtkTransformReal>::New();
 
 		transformFilter->SetTransform(transform);
 		transform->PostMultiply();
 
-		transform->Translate(centre[0], centre[1], centre[2]);
+		transform->Translate(centre);
 		//transform->RotateWXYZ(angle,xAxis, yAxis, zAxis);
 		//transformFilter->Update();
 		appendFilter->AddInputConnection(transformFilter->GetOutputPort());
@@ -515,7 +506,7 @@ void PotentialParticleVTKRecorder::action()
 		if (REC_VELOCITY == true) {
 			vtkIdType pid[1];
 			Vector3r  pos(b->state->pos);
-			pid[0] = pbPos->InsertNextPoint(pos[0], pos[1], pos[2]);
+			pid[0] = pbPos->InsertNextPoint(pos);
 			pbCells->InsertNextCell(1, pid);
 			const Vector3r& vel = b->state->vel;
 			float           v[3]; //v = { vel[0],vel[1],vel[2] };
@@ -534,53 +525,37 @@ void PotentialParticleVTKRecorder::action()
 		}
 		// ################ velocity ###########################
 		polydata->DeleteCells();
-		sample->Delete();
-		contours->Delete();
 		//function->Delete();
-		sample   = NULL;
-		contours = NULL;
 	}
 
 	if (REC_VELOCITY == true) {
-		vtkSmartPointer<vtkUnstructuredGrid> pbUg = vtkSmartPointer<vtkUnstructuredGrid>::New();
+		auto pbUg = vtkSmartPointer<vtkUnstructuredGrid>::New();
 		pbUg->SetPoints(pbPos);
 		pbUg->SetCells(VTK_VERTEX, pbCells);
 		pbUg->GetPointData()->AddArray(pbLinVelVec);
 		pbUg->GetPointData()->AddArray(pbAngVelVec);
 		pbUg->GetPointData()->AddArray(pbLinVelLen);
 		pbUg->GetPointData()->AddArray(pbAngVelLen);
-		vtkSmartPointer<vtkXMLUnstructuredGridWriter> writerA = vtkSmartPointer<vtkXMLUnstructuredGridWriter>::New();
+		auto writerA = vtkSmartPointer<vtkXMLUnstructuredGridWriter>::New();
 		writerA->SetDataModeToAscii();
 		string fv = fileName + "vel." + std::to_string(scene->iter) + ".vtu";
 		writerA->SetFileName(fv.c_str());
-		//  #ifdef YADE_VTK6
 		writerA->SetInputData(pbUg);
-		// #else
-		//		  writerA->SetInput(pbUg);
-		//		#endif
 		writerA->Write();
-		//writerA->Delete();
-		//pbUg->Delete();
 	}
 
 	//###################### bodyId ###############################
 	if (REC_ID == true) {
-		vtkSmartPointer<vtkUnstructuredGrid> pbUg = vtkSmartPointer<vtkUnstructuredGrid>::New();
+		auto pbUg = vtkSmartPointer<vtkUnstructuredGrid>::New();
 		pbUg->SetPoints(pbPosID);
 		pbUg->SetCells(VTK_VERTEX, pbIdCells);
 		pbUg->GetPointData()->AddArray(blockId);
-		vtkSmartPointer<vtkXMLUnstructuredGridWriter> writerA = vtkSmartPointer<vtkXMLUnstructuredGridWriter>::New();
+		auto writerA = vtkSmartPointer<vtkXMLUnstructuredGridWriter>::New();
 		writerA->SetDataModeToAscii();
 		string fv = fileName + "Id." + std::to_string(scene->iter) + ".vtu";
 		writerA->SetFileName(fv.c_str());
-		//#ifdef YADE_VTK6
 		writerA->SetInputData(pbUg);
-		// #else
-		//	  writerA->SetInput(pbUg);
-		//	#endif
 		writerA->Write();
-		//writerA->Delete();
-		//pbUg->Delete();
 	}
 
 
@@ -596,7 +571,7 @@ void PotentialParticleVTKRecorder::action()
 			const ScGeom*   geom = YADE_CAST<ScGeom*>(I->geom.get());
 			vtkIdType       pid[1];
 			Vector3r        pos(geom->contactPoint);
-			pid[0] = pbContactPoint->InsertNextPoint(pos[0], pos[1], pos[2]);
+			pid[0] = pbContactPoint->InsertNextPoint(pos);
 			pbCellsContact->InsertNextCell(1, pid);
 			//intrBodyPos->InsertNextPoint(geom->contactPoint[0],geom->contactPoint[1],geom->contactPoint[2]);
 			// gives _signed_ scalar of normal force, following the convention used in the respective constitutive law
@@ -607,38 +582,30 @@ void PotentialParticleVTKRecorder::action()
 			count++;
 		}
 		if (count > 0) {
-			vtkSmartPointer<vtkUnstructuredGrid> pbUgCP = vtkSmartPointer<vtkUnstructuredGrid>::New();
+			auto pbUgCP = vtkSmartPointer<vtkUnstructuredGrid>::New();
 			pbUgCP->SetPoints(pbContactPoint);
 			pbUgCP->SetCells(VTK_VERTEX, pbCellsContact);
 			pbUgCP->GetPointData()->AddArray(pbNormalForce);
 			pbUgCP->GetPointData()->AddArray(pbShearForce);
-			vtkSmartPointer<vtkXMLUnstructuredGridWriter> writerB = vtkSmartPointer<vtkXMLUnstructuredGridWriter>::New();
+			auto writerB = vtkSmartPointer<vtkXMLUnstructuredGridWriter>::New();
 			writerB->SetDataModeToAscii();
 			string fcontact = fileName + "contactPoint." + std::to_string(scene->iter) + ".vtu";
 			writerB->SetFileName(fcontact.c_str());
-			// #ifdef YADE_VTK6
 			writerB->SetInputData(pbUgCP);
-			// #else
-			//		  writerB->SetInput(pbUgCP);
-			//	  #endif
 			writerB->Write();
-			//writerB->Delete();
-			//pbUgCP->Delete();
 		}
 	}
 
 	// ################ contact point ###########################
 
 
-	vtkSmartPointer<vtkXMLPolyDataWriter> writer = vtkXMLPolyDataWriter::New();
+	auto writer = vtkSmartPointer<vtkXMLPolyDataWriter>::New();
 	writer->SetDataModeToAscii();
 	string fn = fileName + "-pb." + std::to_string(scene->iter) + ".vtp";
 	writer->SetFileName(fn.c_str());
 	writer->SetInputConnection(appendFilter->GetOutputPort());
 	writer->Write();
 
-	writer->Delete();
-
 	//intrBodyPos->Delete();
 	//intrForceN->Delete();
 	//intrAbsForceT->Delete();
