@@ -2,6 +2,7 @@
 // 2013 © Bruno Chareyre <bruno.chareyre@grenoble-inp.fr>
 
 #include "InsertionSortCollider.hpp"
+#include <lib/high-precision/Constants.hpp>
 #include <core/Interaction.hpp>
 #include <core/InteractionContainer.hpp>
 #include <core/Scene.hpp>
@@ -15,6 +16,9 @@
 
 namespace yade { // Cannot have #include directive inside.
 
+using math::max;
+using math::min; // using inside .cpp file is ok.
+
 YADE_PLUGIN((InsertionSortCollider))
 CREATE_LOGGER(InsertionSortCollider);
 
@@ -68,8 +72,8 @@ void InsertionSortCollider::insertionSort(VecBounds& v, InteractionContainer* in
 void InsertionSortCollider::insertionSortParallel(VecBounds& v, InteractionContainer* interactions, Scene*, bool doCollide)
 {
 	assert(!periodic);
-	//assert(v.size()==v.vec.size());
-	if (ompThreads <= 1)
+	///escape parallel sort if 1/ single thread or 2/ not at least 10 bounds per-thread
+	if ((ompThreads <= 1) or (v.size() < size_t(10*ompThreads)))
 		return insertionSort(v, interactions, scene, doCollide);
 
 	Real chunksVerlet = 4 * verletDist; //is 2* the theoretical requirement?
@@ -78,9 +82,9 @@ void InsertionSortCollider::insertionSortParallel(VecBounds& v, InteractionConta
 	}
 
 	///chunks defines subsets of the bounds lists, we make sure they are not too small wrt. verlet dist.
-	std::vector<unsigned> chunks;
-	unsigned              nChunks   = ompThreads;
-	unsigned              chunkSize = unsigned(v.size() / nChunks) + 1;
+	std::vector<Body::id_t> chunks;
+	unsigned                nChunks   = ompThreads;
+	unsigned                chunkSize = unsigned(v.size() / nChunks) + 1;
 	for (unsigned n = 0; n < nChunks; n++)
 		chunks.push_back(n * chunkSize);
 	chunks.push_back(v.size());
@@ -365,11 +369,11 @@ void InsertionSortCollider::action()
 				continue;
 			minR = min(s->radius, minR);
 		}
-		if (std::isinf(minR))
+		if (math::isinf(minR))
 			LOG_WARN("verletDist is set to 0 because no spheres were found. It will result in suboptimal performances, consider setting a positive "
 			         "verletDist in your script.");
 		// if no spheres, disable stride
-		verletDist = std::isinf(minR) ? 0 : std::abs(verletDist) * minR;
+		verletDist = math::isinf(minR) ? 0 : math::abs(verletDist) * minR;
 	}
 	// if interactions are dirty, force reinitialization
 	if (scene->interactions->dirty) {
@@ -437,8 +441,13 @@ void InsertionSortCollider::action()
 				// if initializing periodic, shift coords & record the period into BBj[i].period
 				if (doInitSort && periodic)
 					BBji.coord = cellWrap(BBji.coord, 0, BBj.cellDim, BBji.period);
-				// for each body, copy its minima and maxima, for quick checks of overlaps later
-				//bounds have been all updated when j==0, we can safely copy them here when j==1
+					// for each body, copy its minima and maxima, for quick checks of overlaps later
+					//bounds have been all updated when j==0, we can safely copy them here when j==1
+#if (YADE_REAL_BIT <= 64)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wpragmas"
+// this is to remove warning about manipulating raw memory
+#pragma GCC diagnostic ignored "-Wclass-memaccess"
 				if (bv) {
 					if (BBji.flags.isMin && j == 1)
 						memcpy(&minima[3 * id], &bv->min, 3 * sizeof(Real));
@@ -447,6 +456,26 @@ void InsertionSortCollider::action()
 					memcpy(&minima[3 * id], &maxVect, 3 * sizeof(Real));
 					memcpy(&maxima[3 * id], &maxVect, 3 * sizeof(Real));
 				}
+#pragma GCC diagnostic pop
+#else
+				if (bv) {
+					if (BBji.flags.isMin && j == 1) {
+						minima[3 * id]     = bv->min[0];
+						minima[3 * id + 1] = bv->min[1];
+						minima[3 * id + 2] = bv->min[2];
+					}
+					maxima[3 * id]     = bv->max[0];
+					maxima[3 * id + 1] = bv->max[1];
+					maxima[3 * id + 2] = bv->max[2];
+				} else if (keepListsShort) {
+					minima[3 * id]     = maxVect[0];
+					minima[3 * id + 1] = maxVect[1];
+					minima[3 * id + 2] = maxVect[2];
+					maxima[3 * id]     = maxVect[0];
+					maxima[3 * id + 1] = maxVect[1];
+					maxima[3 * id + 2] = maxVect[2];
+				}
+#endif
 			} else {
 				BBj[i].flags.hasBB = false; /* for vanished body, keep the coordinate as-is, to minimize inversions. */
 #ifdef YADE_MPI
@@ -467,14 +496,17 @@ void InsertionSortCollider::action()
 		/* each inversion in insertionSort calls may add interaction */
 		//1000 bodies is heuristic minimum above which parallel sort is called
 		if (!periodic)
-			for (int i = 0; i < 3; i++) {
+			for (int i = 0; i < 3; i++)
 #ifdef YADE_OPENMP
+			{
 				if (ompThreads <= 1 || nBodies < 1000)
 					insertionSort(BB[i], interactions, scene);
 				else
 					insertionSortParallel(BB[i], interactions, scene);
 			}
 #else
+
+			{
 				insertionSort(BB[i], interactions, scene);
 			}
 #endif
@@ -739,7 +771,7 @@ bool InsertionSortCollider::spatialOverlapPeri(Body::id_t id1, Body::id_t id2, S
 				throw runtime_error(__FILE__ ": Body larger than half of the cell size encountered.");
 			}
 		}
-		int period1 = int(std::floor(lmax));
+		int period1 = int(math::floor(lmax));
 
 		//overlap around zero, on the "+" side
 		if ((lmin - period1) <= overlapTolerance) {
