@@ -7,6 +7,7 @@
 
 #include "RockBolt.hpp"
 //#include<pkg/dem/KnKsLaw.hpp>
+#include <lib/high-precision/Constants.hpp>
 #include <core/Omega.hpp>
 #include <pkg/dem/ScGeom.hpp>
 #include <cstdlib>
@@ -103,7 +104,7 @@ void RockBolt::action()
 				Real     planeD = plane.dot(state1->pos) + pb->d[i] + pb->r;
 				if (intersectPlane(pb, state1, startingPoint, boltDirection, boltLength, jointIntersection, plane, planeD)) {
 					Real sign         = plane.dot(boltDirection);
-					jointIntersection = jointIntersection - Mathr::Sign(sign) * halfActiveLength * boltDirection;
+					jointIntersection = jointIntersection - math::sign(sign) * halfActiveLength * boltDirection;
 					distance.push_back(jointIntersection.norm());
 					jointIntersection = state1->ori.conjugate() * (jointIntersection - state1->pos);
 					intersectNo++;
@@ -193,8 +194,8 @@ void RockBolt::action()
 			Vector3r        nodeDistance
 			        = getNodeDistance(s1, state1, s2, state2, localCoordinates[2 * j - 1], localCoordinates[2 * j]); /* 2 minus 1, from 1 to 2 */
 
-			if (initialLength.size() < abs(blockNo - 1)) {                                                       /*not initialized */
-				initialLength.push_back(nodeDistance.norm() * Mathr::Sign(nodeDistance.dot(boltDirection))); /* negative if there is overlap */
+			if (initialLength.size() < abs(blockNo - 1)) {                                                      /*not initialized */
+				initialLength.push_back(nodeDistance.norm() * math::sign(nodeDistance.dot(boltDirection))); /* negative if there is overlap */
 				initialDirection.push_back(nodeDistance);
 				forces.push_back(0.0);
 				axialForces.push_back(0.0);
@@ -205,7 +206,7 @@ void RockBolt::action()
 				distanceFrCentre.push_back(0.0);
 			} else {
 				if (resetLengthInit == true) {
-					initialLength[j - 1] = nodeDistance.norm() * Mathr::Sign(nodeDistance.dot(boltDirection));
+					initialLength[j - 1] = nodeDistance.norm() * math::sign(nodeDistance.dot(boltDirection));
 					resetLengthInit      = false;
 				}
 				Vector3r direction = nodeDistance;
@@ -217,10 +218,10 @@ void RockBolt::action()
 				//}else{
 				dirSign = direction.dot(boltDirection); //FIXME assume special case does not happen, i.e., activeLength is long enough
 
-				Vector3r axialForce = (normalStiffness * (Mathr::Sign(dirSign) * nodeDistance.norm() - initialLength[j - 1]) + preTension)
-				        * (Mathr::Sign(dirSign)
+				Vector3r axialForce = (normalStiffness * (math::sign(dirSign) * nodeDistance.norm() - initialLength[j - 1]) + preTension)
+				        * (math::sign(dirSign)
 				           * direction); /* the last term makes sure tension is always pointing in the direction of boltdirection */
-				//Vector3r axialForce = (axialStiffness/initialLength[j-1]*(Mathr::Sign(dirSign)*nodeDistance.norm() - initialLength[j-1])+preTension)*(Mathr::Sign(dirSign)*direction);/* the last term makes sure tension is always pointing in the direction of boltdirection */
+				//Vector3r axialForce = (axialStiffness/initialLength[j-1]*(math::sign(dirSign)*nodeDistance.norm() - initialLength[j-1])+preTension)*(math::sign(dirSign)*direction);/* the last term makes sure tension is always pointing in the direction of boltdirection */
 				Vector3r shearDir = boltDirection.cross(Vector3r(0, 1, 0));
 				shearDir.normalize();
 				Vector3r shearForce = shearStiffness * (nodeDistance.dot(shearDir)) * shearDir;
@@ -232,7 +233,7 @@ void RockBolt::action()
 				}
 				axialForces[j - 1] = axialForce.norm();
 				shearForces[j - 1] = shearForce.norm();
-				forces[j - 1]      = (axialForce + shearForce).norm(); //*Mathr::Sign(dirSign);
+				forces[j - 1]      = (axialForce + shearForce).norm(); //*math::sign(dirSign);
 				averageForce += forces[j - 1];
 				maxForce = std::max(maxForce, forces[j - 1]);
 
@@ -259,9 +260,9 @@ void RockBolt::action()
 		int                                blockNo      = blockIDs.size();
 
 		/// BOLT FORCE //
-		vtkSmartPointer<vtkPoints>     boltNodalPoints      = vtkSmartPointer<vtkPoints>::New();
+		vtkSmartPointer<vtkPointsReal> boltNodalPoints      = vtkSmartPointer<vtkPointsReal>::New();
 		vtkSmartPointer<vtkCellArray>  boltNodalPointsCells = vtkSmartPointer<vtkCellArray>::New();
-		vtkSmartPointer<vtkPoints>     boltNode             = vtkSmartPointer<vtkPoints>::New();
+		vtkSmartPointer<vtkPointsReal> boltNode             = vtkSmartPointer<vtkPointsReal>::New();
 		vtkSmartPointer<vtkCellArray>  boltNodeCells        = vtkSmartPointer<vtkCellArray>::New();
 		vtkSmartPointer<vtkFloatArray> boltNodalForce       = vtkSmartPointer<vtkFloatArray>::New();
 		boltNodalForce->SetNumberOfComponents(3);
@@ -285,9 +286,9 @@ void RockBolt::action()
 			appendFilter->AddInputConnection(lineSource->GetOutputPort());
 
 			vtkIdType pid2[1];
-			pid2[0] = boltNodalPoints->InsertNextPoint(globalPoint1[0], globalPoint1[1], globalPoint1[2]);
+			pid2[0] = boltNodalPoints->InsertNextPoint(globalPoint1);
 			boltNodalPointsCells->InsertNextCell(1, pid2);
-			pid2[0] = boltNodalPoints->InsertNextPoint(globalPoint2[0], globalPoint2[1], globalPoint2[2]);
+			pid2[0] = boltNodalPoints->InsertNextPoint(globalPoint2);
 			boltNodalPointsCells->InsertNextCell(1, pid2);
 
 			if (i < blockNo - 1) {
@@ -305,7 +306,7 @@ void RockBolt::action()
 				/* try to draw forces */
 				vtkIdType pid[1];
 				Vector3r  midPoint = 0.5 * (globalPoint2 + globalPoint3);
-				pid[0]             = boltNode->InsertNextPoint(midPoint[0], midPoint[1], midPoint[2]);
+				pid[0]             = boltNode->InsertNextPoint(midPoint);
 				boltNodeCells->InsertNextCell(1, pid);
 				Vector3r plotDirection = boltDirection.cross(Vector3r(0, 1, 0));
 				if (plotDirection.dot(Vector3r(1, 0, 0)) < 0.0) {
@@ -392,7 +393,7 @@ Real RockBolt::evaluateFNoSphereVol(const PotentialBlock* s1, const State* state
 	int  insideCount = 0;
 	for (int i = 0; i < planeNo; i++) {
 		Real plane = s1->a[i] * x + s1->b[i] * y + s1->c[i] * z - s1->d[i] - 1.0002 * r; //-pow(10,-10);
-		if (Mathr::Sign(plane) * 1.0 < 0.0) {
+		if (math::sign(plane) * 1.0 < 0.0) {
 			insideCount++;
 		}
 	}
@@ -428,19 +429,19 @@ bool RockBolt::installBolts(
 	Real s      = 0.0;
 	//bool converge = true;
 
-	Matrix3r        Q1 = (state1->ori.conjugate()).toRotationMatrix();
-	Eigen::MatrixXd A1 = Eigen::MatrixXd::Zero(planeNoA, 3);
+	Matrix3r Q1 = (state1->ori.conjugate()).toRotationMatrix();
+	MatrixXr A1 = MatrixXr::Zero(planeNoA, 3);
 	for (int i = 0; i < planeNoA; i++) {
 		A1(i, 0) = s1->a[i];
 		A1(i, 1) = s1->b[i];
 		A1(i, 2) = s1->c[i];
 	}
-	Eigen::MatrixXd AQ1 = A1 * Q1;
-	Eigen::MatrixXd pos1(3, 1);
-	pos1(0, 0)             = state1->pos.x();
-	pos1(1, 0)             = state1->pos.y();
-	pos1(2, 0)             = state1->pos.z();
-	Eigen::MatrixXd Q1pos1 = AQ1 * pos1;
+	MatrixXr AQ1 = A1 * Q1;
+	MatrixXr pos1(3, 1);
+	pos1(0, 0)      = state1->pos.x();
+	pos1(1, 0)      = state1->pos.y();
+	pos1(2, 0)      = state1->pos.z();
+	MatrixXr Q1pos1 = AQ1 * pos1;
 
 
 	ClpSimplex model2;
