@@ -4,6 +4,7 @@
 #if defined(YADE_POTENTIAL_BLOCKS) && defined(YADE_VTK)
 #include "RockLiningGlobal.hpp"
 #include <lib/compatibility/VTKCompatibility.hpp> // fix InsertNextTupleValue → InsertNextTuple name change (and others in the future)
+#include <lib/high-precision/Constants.hpp>
 //#include<pkg/dem/KnKsLaw.hpp>
 #include <core/Material.hpp>
 #include <core/Omega.hpp>
@@ -236,7 +237,7 @@ void RockLiningGlobal::action()
 			sigmaMax[j]           = axialForces[j] / area + fabs(moment[j]) * (2.0 * liningThickness) / Inertia;
 			sigmaMin[j]           = axialForces[j] / area - fabs(moment[j]) * (2.0 * liningThickness) / Inertia;
 			Real displacementSign = (state1->pos - refPos[j]).dot(refPos[j]);
-			displacement[j]       = Mathr::Sign(displacementSign) * (state1->pos - refPos[j]).norm();
+			displacement[j]       = math::sign(displacementSign) * (state1->pos - refPos[j]).norm();
 			Vector3r dir          = refPos[j];
 			dir.normalize();
 			radialDisplacement[j] = (state1->pos - refPos[j]).dot(dir);
@@ -351,7 +352,7 @@ void RockLiningGlobal::action()
 		int                                blockNo      = blockIDs.size();
 
 		/// lining FORCE //
-		vtkSmartPointer<vtkPoints>     liningNode        = vtkSmartPointer<vtkPoints>::New();
+		vtkSmartPointer<vtkPointsReal> liningNode        = vtkSmartPointer<vtkPointsReal>::New();
 		vtkSmartPointer<vtkCellArray>  liningNodeCells   = vtkSmartPointer<vtkCellArray>::New();
 		vtkSmartPointer<vtkFloatArray> liningNodalMoment = vtkSmartPointer<vtkFloatArray>::New();
 		liningNodalMoment->SetNumberOfComponents(3);
@@ -393,7 +394,7 @@ void RockLiningGlobal::action()
 			/* try to draw forces */
 			vtkIdType pid[1];
 			Vector3r  midPoint = globalPoint1; //  0.5*(globalPoint1+globalPoint2);
-			pid[0]             = liningNode->InsertNextPoint(midPoint[0], midPoint[1], midPoint[2]);
+			pid[0]             = liningNode->InsertNextPoint(midPoint);
 			liningNodeCells->InsertNextCell(1, pid);
 			Vector3r plotDirection = midPoint;
 			plotDirection.normalize();
@@ -531,7 +532,7 @@ Real RockLiningGlobal::evaluateFNoSphereVol(const PotentialBlock* s1, const Stat
 	int  insideCount = 0;
 	for (int i = 0; i < planeNo; i++) {
 		Real plane = s1->a[i] * x + s1->b[i] * y + s1->c[i] * z - s1->d[i] - 1.0002 * r; //-pow(10,-10);
-		if (Mathr::Sign(plane) * 1.0 < 0.0) {
+		if (math::sign(plane) * 1.0 < 0.0) {
 			insideCount++;
 		}
 	}
@@ -568,19 +569,19 @@ bool RockLiningGlobal::installLining(
 	Real s      = 0.0;
 	//bool converge = true;
 
-	Matrix3r        Q1 = (state1->ori.conjugate()).toRotationMatrix();
-	Eigen::MatrixXd A1 = Eigen::MatrixXd::Zero(planeNoA, 3);
+	Matrix3r Q1 = (state1->ori.conjugate()).toRotationMatrix();
+	MatrixXr A1 = MatrixXr::Zero(planeNoA, 3);
 	for (int i = 0; i < planeNoA; i++) {
 		A1(i, 0) = s1->a[i];
 		A1(i, 1) = s1->b[i];
 		A1(i, 2) = s1->c[i];
 	}
-	Eigen::MatrixXd AQ1 = A1 * Q1;
-	Eigen::MatrixXd pos1(3, 1);
-	pos1(0, 0)             = state1->pos.x();
-	pos1(1, 0)             = state1->pos.y();
-	pos1(2, 0)             = state1->pos.z();
-	Eigen::MatrixXd Q1pos1 = AQ1 * pos1;
+	MatrixXr AQ1 = A1 * Q1;
+	MatrixXr pos1(3, 1);
+	pos1(0, 0)      = state1->pos.x();
+	pos1(1, 0)      = state1->pos.y();
+	pos1(2, 0)      = state1->pos.z();
+	MatrixXr Q1pos1 = AQ1 * pos1;
 
 
 	ClpSimplex model2;
