@@ -3,11 +3,11 @@
 // © 2006 Bruno Chareyre <bruno.chareyre@grenoble-inp.fr>
 
 #pragma once
-#include<core/Interaction.hpp>
-#include<core/IGeom.hpp>
-#include<core/State.hpp>
-#include<lib/base/Math.hpp>
-#include<pkg/dem/DemXDofGeom.hpp>
+#include <lib/base/Math.hpp>
+#include <core/IGeom.hpp>
+#include <core/Interaction.hpp>
+#include <core/State.hpp>
+#include <pkg/dem/DemXDofGeom.hpp>
 
 namespace yade { // Cannot have #include directive inside.
 
@@ -18,41 +18,56 @@ namespace yade { // Cannot have #include directive inside.
 
 #define SCG_SHEAR
 
-class ScGeom: public GenericSpheresContact {
-	private:
-		//cached values
-		Vector3r twist_axis;//rotation vector around normal
-		Vector3r orthonormal_axis;//rotation vector in contact plane
-	public:
-		// inherited from GenericSpheresContact: Vector3r& normal;
-		Real &radius1, &radius2;
-		virtual ~ScGeom();
-		inline ScGeom& operator= (const ScGeom& source){
-			normal=source.normal; contactPoint=source.contactPoint;
-			twist_axis=source.twist_axis; orthonormal_axis=source.orthonormal_axis;
-			radius1=source.radius1; radius2=source.radius2;
-			penetrationDepth=source.penetrationDepth; shearInc=source.shearInc;
-			return *this;}
+class ScGeom : public GenericSpheresContact {
+private:
+	//cached values
+	Vector3r twist_axis;       //rotation vector around normal
+	Vector3r orthonormal_axis; //rotation vector in contact plane
+public:
+	// inherited from GenericSpheresContact: Vector3r& normal;
+	Real &radius1, &radius2;
+	virtual ~ScGeom();
+	inline ScGeom& operator=(const ScGeom& source)
+	{
+		normal           = source.normal;
+		contactPoint     = source.contactPoint;
+		twist_axis       = source.twist_axis;
+		orthonormal_axis = source.orthonormal_axis;
+		radius1          = source.radius1;
+		radius2          = source.radius2;
+		penetrationDepth = source.penetrationDepth;
+		shearInc         = source.shearInc;
+		return *this;
+	}
 
-		//!precompute values of shear increment and interaction rotation data. Update contact normal to the currentNormal value. Precondition : the value of normal is not updated outside (and before) this function.
-		void precompute(const State& rbp1, const State& rbp2, const Scene* scene, const shared_ptr<Interaction>& c, const Vector3r& currentNormal, bool isNew, const Vector3r& shift2, bool avoidGranularRatcheting=true);
+	//!precompute values of shear increment and interaction rotation data. Update contact normal to the currentNormal value. Precondition : the value of normal is not updated outside (and before) this function.
+	void precompute(
+	        const State&                   rbp1,
+	        const State&                   rbp2,
+	        const Scene*                   scene,
+	        const shared_ptr<Interaction>& c,
+	        const Vector3r&                currentNormal,
+	        bool                           isNew,
+	        const Vector3r&                shift2,
+	        bool                           avoidGranularRatcheting = true);
 
-		//! Rotates a "shear" vector to keep track of contact orientation. Returns reference of the updated vector.
-		Vector3r& rotate(Vector3r& tangentVector) const;
-		Vector3r& rotateNonSpherical(Vector3r& tangentVector) const; //FIXME
+	//! Rotates a "shear" vector to keep track of contact orientation. Returns reference of the updated vector.
+	Vector3r& rotate(Vector3r& tangentVector) const;
+	Vector3r& rotateNonSpherical(Vector3r& tangentVector) const; //FIXME
 
-		const Vector3r& shearIncrement() const {return shearInc;}
+	const Vector3r& shearIncrement() const { return shearInc; }
 
-		// Add method which returns the relative velocity (then, inside the contact law, this can be split into shear and normal component). Handle periodicity.
-		Vector3r getIncidentVel(const State* rbp1, const State* rbp2, Real dt, const Vector3r& shiftVel, const Vector3r& shift2, bool avoidGranularRatcheting=true);
-		// Implement another version of getIncidentVel which does not handle periodicity.
-		Vector3r getIncidentVel(const State* rbp1, const State* rbp2, Real dt, bool avoidGranularRatcheting=true);
-		// Add function to get the relative angular velocity (useful to determine bending moment at the contact level)
-		Vector3r getRelAngVel(const State* rbp1, const State* rbp2, Real dt);
-		
-		// convenience version to be called from python
-		Vector3r getIncidentVel_py(shared_ptr<Interaction> i, bool avoidGranularRatcheting);
-		Vector3r getRelAngVel_py(shared_ptr<Interaction> i);
+	// Add method which returns the relative velocity (then, inside the contact law, this can be split into shear and normal component). Handle periodicity.
+	Vector3r
+	getIncidentVel(const State* rbp1, const State* rbp2, Real dt, const Vector3r& shiftVel, const Vector3r& shift2, bool avoidGranularRatcheting = true);
+	// Implement another version of getIncidentVel which does not handle periodicity.
+	Vector3r getIncidentVel(const State* rbp1, const State* rbp2, Real dt, bool avoidGranularRatcheting = true);
+	// Add function to get the relative angular velocity (useful to determine bending moment at the contact level)
+	Vector3r getRelAngVel(const State* rbp1, const State* rbp2, Real dt);
+
+	// convenience version to be called from python
+	Vector3r getIncidentVel_py(shared_ptr<Interaction> i, bool avoidGranularRatcheting);
+	Vector3r getRelAngVel_py(shared_ptr<Interaction> i);
 
 	// clang-format off
 		YADE_CLASS_BASE_DOC_ATTRS_INIT_CTOR_PY(ScGeom,GenericSpheresContact,
@@ -95,17 +110,17 @@ Tangential displacement increment over last step then reads\n\
 		.def("relAngVel",&ScGeom::getRelAngVel_py,(boost::python::arg("i")),"Return relative angular velocity of the interaction.")
 	);
 	// clang-format on
-	REGISTER_CLASS_INDEX(ScGeom,GenericSpheresContact);
+	REGISTER_CLASS_INDEX(ScGeom, GenericSpheresContact);
 };
 REGISTER_SERIALIZABLE(ScGeom);
 
-class ScGeom6D: public ScGeom {
-	public:
-		virtual ~ScGeom6D();
-		const Real& getTwist() const {return twist;}
-		const Vector3r& getBending() const {return bending;}
-		void precomputeRotations(const State& rbp1, const State& rbp2, bool isNew, bool creep=false);
-		void initRotations(const State& rbp1, const State& rbp2);
+class ScGeom6D : public ScGeom {
+public:
+	virtual ~ScGeom6D();
+	const Real&     getTwist() const { return twist; }
+	const Vector3r& getBending() const { return bending; }
+	void            precomputeRotations(const State& rbp1, const State& rbp2, bool isNew, bool creep = false);
+	void            initRotations(const State& rbp1, const State& rbp2);
 	// clang-format off
 		YADE_CLASS_BASE_DOC_ATTRS_INIT_CTOR_PY(ScGeom6D,ScGeom,"Class representing :yref:`geometry<IGeom>` of two :yref:`bodies<Body>` in contact. The contact has 6 DOFs (normal, 2×shear, twist, 2xbending) and uses :yref:`ScGeom` incremental algorithm for updating shear.",
 		((Quaternionr,initialOrientation1,Quaternionr(1.0,0.0,0.0,0.0),(Attr::readonly),"Orientation of body 1 one at initialisation time |yupdate|"))
@@ -119,17 +134,17 @@ class ScGeom6D: public ScGeom {
  		/* py */
 	);
 	// clang-format on
-	REGISTER_CLASS_INDEX(ScGeom6D,ScGeom);
+	REGISTER_CLASS_INDEX(ScGeom6D, ScGeom);
 };
 REGISTER_SERIALIZABLE(ScGeom6D);
 
 
-class ChCylGeom6D: public ScGeom6D {
-	public:
-		virtual ~ChCylGeom6D();
-		State fictiousState1;
-		State fictiousState2;
-		Real relPos1, relPos2;
+class ChCylGeom6D : public ScGeom6D {
+public:
+	virtual ~ChCylGeom6D();
+	State fictiousState1;
+	State fictiousState2;
+	Real  relPos1, relPos2;
 	// clang-format off
 		YADE_CLASS_BASE_DOC_ATTRS_INIT_CTOR_PY(ChCylGeom6D,ScGeom6D,"Test",
 		/*attributes*/
@@ -139,9 +154,8 @@ class ChCylGeom6D: public ScGeom6D {
 		/* py */
 	);
 	// clang-format on
-	REGISTER_CLASS_INDEX(ChCylGeom6D,ScGeom6D);
+	REGISTER_CLASS_INDEX(ChCylGeom6D, ScGeom6D);
 };
 REGISTER_SERIALIZABLE(ChCylGeom6D);
 
 } // namespace yade
-
