@@ -1,6 +1,7 @@
 // © 2009 Václav Šmilauer <eudoxos@arcig.cz>
 
 #include <lib/base/AliasNamespaces.hpp>
+#include <lib/high-precision/Constants.hpp>
 #include <core/Omega.hpp>
 #include <core/Scene.hpp>
 #include <core/Timing.hpp>
@@ -11,6 +12,9 @@
 
 namespace yade { // Cannot have #include directive inside.
 
+using math::max;
+using math::min; // using inside .cpp file is ok.
+
 // not a serializable in the sense of YADE_PLUGIN
 
 CREATE_LOGGER(SpherePack);
@@ -25,7 +29,11 @@ void SpherePack::fromList(const py::list& l)
 		const py::tuple&      t = py::extract<py::tuple>(l[i]);
 		py::extract<Vector3r> vec(t[0]);
 		if (vec.check()) {
+#if (YADE_REAL_BIT <= 80)
 			pack.push_back(Sph(vec(), py::extract<double>(t[1]), (py::len(t) > 2 ? py::extract<int>(t[2]) : -1)));
+#else
+			pack.push_back(Sph(vec(), static_cast<Real>(py::extract<Real>(t[1])), (py::len(t) > 2 ? py::extract<int>(t[2]) : -1)));
+#endif
 			continue;
 		}
 		PyErr_SetString(PyExc_TypeError, "List elements must be (Vector3, float) or (Vector3, float, int)!");
@@ -70,7 +78,7 @@ void SpherePack::fromFile(const string& file)
 
 void SpherePack::toFile(const string& fname) const
 {
-	ofstream f(fname.c_str());
+	std::ofstream f(fname.c_str());
 	if (!f.good()) {
 		throw runtime_error("Unable to open file `" + fname + "'");
 	}
@@ -118,7 +126,7 @@ long SpherePack::makeCloud(
 	isPeriodic = periodic;
 
 	std::random_device               rd;
-	std::mt19937                     gen(rd());
+	std::mt19937                     gen(seed >= 0 ? seed : rd());
 	std::uniform_real_distribution<> dis(0.0, 1.0);
 
 	vector<Real> psdRadii; // holds plain radii (rather than diameters), scaled down in some situations to get the target number
@@ -132,7 +140,7 @@ long SpherePack::makeCloud(
 		LOG_WARN("hSize can be defined only for periodic cells.");
 	Real     volume   = hSize.determinant();
 	Matrix3r invHsize = hSize.inverse();
-	Real area = std::abs(size[0] * size[2] + size[0] * size[1] + size[1] * size[2]); //2 terms will be null if one coordinate is 0, the other is the area
+	Real area = math::abs(size[0] * size[2] + size[0] * size[1] + size[1] * size[2]); //2 terms will be null if one coordinate is 0, the other is the area
 	if (!volume) {
 		if (hSizeFound)
 			throw invalid_argument("The period defined by hSize has null length in at least one direction, this is not supported. Define flat "
@@ -299,10 +307,10 @@ long SpherePack::makeCloud(
 					} else { //not aligned, find closest neighbor in a cube of size 1, then transform distance to cartesian coordinates
 						Vector3r c1c2 = invHsize * (pack[j].c - c);
 						for (int axis = 0; axis < 3; axis++) {
-							if (std::abs(c1c2[axis]) < std::abs(c1c2[axis] - Mathr::Sign(c1c2[axis])))
+							if (math::abs(c1c2[axis]) < math::abs(c1c2[axis] - math::sign(c1c2[axis])))
 								dr[axis] = c1c2[axis];
 							else
-								dr[axis] = c1c2[axis] - Mathr::Sign(c1c2[axis]);
+								dr[axis] = c1c2[axis] - math::sign(c1c2[axis]);
 						}
 						dr = hSize * dr; //now in cartesian coordinates
 					}
@@ -449,7 +457,7 @@ py::tuple SpherePack::psd(int bins, bool mass) const
 	return py::make_tuple(edges, cumm);
 }
 
-long SpherePack::makeClumpCloud(const Vector3r& mn, const Vector3r& mx, const vector<shared_ptr<SpherePack>>& _clumps, bool periodic, int num)
+long SpherePack::makeClumpCloud(const Vector3r& mn, const Vector3r& mx, const vector<shared_ptr<SpherePack>>& _clumps, bool periodic, int num, int seed)
 {
 	// recenter given clumps and compute their margins
 	vector<SpherePack> clumps; /* vector<Vector3r> margins; */
@@ -478,7 +486,7 @@ long SpherePack::makeClumpCloud(const Vector3r& mn, const Vector3r& mx, const ve
 	const auto                       maxTry = 200;
 	int                              nGen   = 0; // number of clumps generated
 	std::random_device               rd;
-	std::mt19937                     gen(rd());
+	std::mt19937                     gen(seed >= 0 ? seed : rd());
 	std::uniform_real_distribution<> dis(0.0, 1.0);
 	while (nGen < num || num < 0) {
 		int clumpChoice = (int)(dis(gen) * (clumps.size() - 1e-20));
@@ -712,7 +720,7 @@ void SpherePack::scale(Real scale)
 	cellSize *= scale;
 	for (auto& s : pack) {
 		s.c = scale * (s.c - mid) + mid;
-		s.r *= std::abs(scale);
+		s.r *= math::abs(scale);
 	}
 }
 
