@@ -12,10 +12,9 @@
 
 namespace yade { // Cannot have #include directive inside.
 
-class Gl1_DeformableElement : public GlShapeFunctor
-{	
-	public:
-		virtual void go(const shared_ptr<Shape>&, const shared_ptr<State>&,bool,const GLViewInfo&);
+class Gl1_DeformableElement : public GlShapeFunctor {
+public:
+	virtual void go(const shared_ptr<Shape>&, const shared_ptr<State>&, bool, const GLViewInfo&);
 	// clang-format off
 		YADE_CLASS_BASE_DOC(Gl1_DeformableElement,GlShapeFunctor,"Renders :yref:`Node` object"
 		);
@@ -26,4 +25,3 @@ class Gl1_DeformableElement : public GlShapeFunctor
 REGISTER_SERIALIZABLE(Gl1_DeformableElement);
 
 } // namespace yade
-
