@@ -10,94 +10,94 @@
 
 /* Theoretical framework and experimental validation presented in:
 
-Caulk, R. and Chareyre, B. (2019) An open framework for the simulation of thermal-hydraulic-mechanical processes in discrete element systems. Thermal Process Engineering: Proceedings of DEM8, Enschede Netherlands, July 2019. 
+Caulk, R. and Chareyre, B. (2019) An open framework for the simulation of thermal-hydraulic-mechanical processes in discrete element systems. Thermal Process Engineering: Proceedings of DEM8, Enschede Netherlands, July 2019.
 
 */
 
 //#define THERMAL
 #ifdef THERMAL
-#ifdef YADE_OPENMP  
-#pragma once 
+#ifdef YADE_OPENMP
+#pragma once
 
-#include<core/PartialEngine.hpp>
-#include<core/State.hpp>
-#include<pkg/dem/JointedCohesiveFrictionalPM.hpp>
-#include<pkg/dem/ScGeom.hpp>
-#include<pkg/common/Dispatching.hpp>
+#include <core/PartialEngine.hpp>
+#include <core/State.hpp>
+#include <pkg/common/Dispatching.hpp>
+#include <pkg/dem/JointedCohesiveFrictionalPM.hpp>
+#include <pkg/dem/ScGeom.hpp>
 
 #ifdef FLOW_ENGINE
 //#include<pkg/pfv/FlowEngine.hpp>
-#include<lib/triangulation/Tesselation.h>
-#include<lib/triangulation/FlowBoundingSphere.hpp>
 #include "FlowEngine_FlowEngineT.hpp"
-#include<pkg/dem/TesselationWrapper.hpp>
-#include<lib/triangulation/Network.hpp>
+#include <lib/triangulation/FlowBoundingSphere.hpp>
+#include <lib/triangulation/Network.hpp>
+#include <lib/triangulation/Tesselation.h>
+#include <pkg/dem/TesselationWrapper.hpp>
 #endif
 
 namespace yade { // Cannot have #include directive inside.
 
-class ThermalEngine : public PartialEngine
-{
-	public:
-		typedef TemplateFlowEngine_FlowEngineT<FlowCellInfo_FlowEngineT,FlowVertexInfo_FlowEngineT> FlowEngineT;
-		typedef FlowEngineT::Tesselation					Tesselation;
-		typedef FlowEngineT::RTriangulation					RTriangulation;
-		typedef FlowEngineT::FiniteCellsIterator				FiniteCellsIterator;
-		typedef RTriangulation::Finite_facets_iterator				FiniteFacetsIterator;
-		typedef FlowEngineT::CellHandle						CellHandle;
-		typedef FlowEngineT::VertexHandle	VertexHandle;
-		typedef FlowEngineT::Facet						Facet;
-		typedef std::vector<CellHandle>		VectorCell;
-		typedef typename VectorCell::iterator		VCellIterator;
+class ThermalEngine : public PartialEngine {
+public:
+	typedef TemplateFlowEngine_FlowEngineT<FlowCellInfo_FlowEngineT, FlowVertexInfo_FlowEngineT> FlowEngineT;
+	typedef FlowEngineT::Tesselation                                                             Tesselation;
+	typedef FlowEngineT::RTriangulation                                                          RTriangulation;
+	typedef FlowEngineT::FiniteCellsIterator                                                     FiniteCellsIterator;
+	typedef RTriangulation::Finite_facets_iterator                                               FiniteFacetsIterator;
+	typedef FlowEngineT::CellHandle                                                              CellHandle;
+	typedef FlowEngineT::VertexHandle                                                            VertexHandle;
+	typedef FlowEngineT::Facet                                                                   Facet;
+	typedef std::vector<CellHandle>                                                              VectorCell;
+	typedef typename VectorCell::iterator                                                        VCellIterator;
 
-	public:
-		Scene* scene;
-		bool energySet; //initialize the internal energy of the particles
-		FlowEngineT* flow;
-        	bool timeStepEstimated;
-       		Real thermalDT;
-        	bool conductionIter;
-        	int elapsedIters;
-        	int conductionIterPeriod;
-        	Real elapsedTime;
-        	bool first;
-        	bool runConduction;
-        	Real maxTimeStep;
-		Real Pr;
-		Real Nu;
-		Real NutimesFluidK;
-		double cavitySolidVolumeChange;
-		double cavityVolume;
-		double cavityDtemp;
-		
-		virtual ~ThermalEngine();
-		virtual void action();
-		void setReynoldsNumbers();
-		void setInitialValues();
-		void applyTempDeltaToSolids(Real delT);
-		void resetFlowBoundaryTemps();
-		void resetBoundaryFluxSums();
-		void setConductionBoundary();
-		void thermalExpansion();
-		void initializeInternalEnergy();
-        	void computeNewPoreTemperatures();
-        	void computeNewParticleTemperatures();
-		void computeSolidFluidFluxes();
-		void computeFluidFluidConduction();
-		void updateForces();
-		void computeVertexSphericalArea();
-		void computeFlux(CellHandle& cell, const shared_ptr<Body>& b, const double surfaceArea);
-		void computeSolidSolidFluxes();
-        	void timeStepEstimate();
-		CVector cellBarycenter(const CellHandle& cell);
-        	void computeCellVolumeChangeFromDeltaTemp(CellHandle& cell,double cavDens);
-		void accountForCavitySolidVolumeChange();
-		void accountForCavityThermalVolumeChange();
-		void unboundCavityParticles();
-        	void computeCellVolumeChangeFromSolidVolumeChange(CellHandle& cell);
-        	Real getThermalDT() {return thermalDT;}
-        	int getConductionIterPeriod() {return conductionIterPeriod;}
-        	Real getMaxTimeStep() {return maxTimeStep;}
+public:
+	Scene*       scene;
+	bool         energySet; //initialize the internal energy of the particles
+	FlowEngineT* flow;
+	bool         timeStepEstimated;
+	Real         thermalDT;
+	bool         conductionIter;
+	int          elapsedIters;
+	int          conductionIterPeriod;
+	Real         elapsedTime;
+	bool         first;
+	bool         runConduction;
+	Real         maxTimeStep;
+	Real         Pr;
+	Real         Nu;
+	Real         NutimesFluidK;
+	Real         cavitySolidVolumeChange;
+	Real         cavityVolume;
+	Real         cavityDtemp;
+
+	virtual ~ThermalEngine();
+	virtual void action();
+	void         setReynoldsNumbers();
+	void         setInitialValues();
+	void         applyTempDeltaToSolids(Real delT);
+	void         resetFlowBoundaryTemps();
+	void         resetBoundaryFluxSums();
+	void         setConductionBoundary();
+	void         thermalExpansion();
+	void         initializeInternalEnergy();
+	void         computeNewPoreTemperatures();
+	void         computeNewParticleTemperatures();
+	void         computeSolidFluidFluxes();
+	void         computeFluidFluidConduction();
+	void         updateForces();
+	void         computeVertexSphericalArea();
+	void         computeFlux(CellHandle& cell, const shared_ptr<Body>& b, const Real surfaceArea);
+	void         computeSolidSolidFluxes();
+	void         timeStepEstimate();
+	CVector      cellBarycenter(const CellHandle& cell);
+	void         computeCellVolumeChangeFromDeltaTemp(CellHandle& cell, Real cavDens);
+	void         accountForCavitySolidVolumeChange();
+	void         accountForCavityThermalVolumeChange();
+	void         unboundCavityParticles();
+	void         computeCellVolumeChangeFromSolidVolumeChange(CellHandle& cell);
+	Real         getThermalDT() const { return thermalDT; }
+	int          getConductionIterPeriod() const { return conductionIterPeriod; }
+	Real         getMaxTimeStep() const { return maxTimeStep; }
+	//void         applyBoundaryHeatFluxes();
 	// clang-format off
 		YADE_CLASS_BASE_DOC_ATTRS_INIT_CTOR_PY(ThermalEngine,PartialEngine,"An engine typically used in combination with FlowEngine to simulate thermal-hydraulic-mechanical processes. Framework description and demonstration presented within the following paper [Caulk2019a]_ :Caulk, R.A. and Chareyre, B. (2019) An open framework for the simulation of thermal-hydraulic-mechanical processes in discrete element systems. Thermal Process Engineering: Proceedings of DEM8 International Conference for Discrete Element Methods, Enschede Netherlands, July 2019.",
 		/*attributes*/
@@ -110,8 +110,8 @@ class ThermalEngine : public PartialEngine
         	((bool,solidThermoMech,true,,"Activates thermoMech"))
 		((bool,ignoreFictiousConduction,false,,"Allows user to ignore conduction between fictious cells and particles. Mainly for debugging purposes."))
 		((vector<bool>, bndCondIsTemperature, vector<bool>(6,false),,"defines the type of boundary condition for each side. True if temperature is imposed, False for no heat-flux. Indices can be retrieved with :yref:`FlowEngine::xmin` and friends."))
-		((vector<double>, thermalBndCondValue, vector<double>(6,0),,"Imposed value of a boundary condition."))
-		((vector<double>, thermalBndFlux, vector<double>(6,0),,"Flux through thermal boundary."))
+		((vector<Real>, thermalBndCondValue, vector<Real>(6,0),,"Imposed value of a boundary condition."))
+		((vector<Real>, thermalBndFlux, vector<Real>(6,0),,"Flux through thermal boundary."))
 		((bool,boundarySet,false,,"set false to change boundary conditions"))
 		((bool,useKernMethod,false,,"flag to use Kern method for thermal conductivity area calc"))
 		((bool,useHertzMethod,false,,"flag to use hertzmethod for thermal conductivity area calc"))
@@ -129,12 +129,12 @@ class ThermalEngine : public PartialEngine
         	((Real
 ,fluidK,0.580,,"Thermal conductivity of the fluid."))
 		((Real,uniformReynolds,-1.,,"Control reynolds number in all cells (mostly debugging purposes). "))
-		((double,fluidBulkModulus,0,,"If > 0, thermalEngine uses this value instead of flow.fluidBulkModulus."))
+		((Real,fluidBulkModulus,0,,"If > 0, thermalEngine uses this value instead of flow.fluidBulkModulus."))
 		((Real, delT, 0,,"Allows user to apply a delT to solids and observe macro thermal expansion. Resets to 0 after one conduction step."))
-        	((double,tsSafetyFactor,0.8,,"Allow user to control the timstep estimate with a safety factor. Default 0.8. If <= 0, thermal timestep is equal to DEM"))
-        	((double,porosityFactor,0,,"If >0, factors the fluid thermal expansion. Useful for simulating low porosity matrices."))
-        	((bool,tempDependentFluidBeta,false,,"If true, fluid volumetric thermal expansion is temperature dependent (linear model between 20-70 degC)"))
-        	((double,minimumFluidCondDist,0,,"Useful for maintaining stability despite poor external triangulations involving flat tetrahedrals. Consider setting to minimum particle diameter to keep scale."))
+        	((Real,tsSafetyFactor,0.8,,"Allow user to control the timstep estimate with a safety factor. Default 0.8. If <= 0, thermal timestep is equal to DEM"))
+        	((Real,porosityFactor,0,,"If >0, factors the fluid thermal expansion. Useful for simulating low porosity matrices."))
+        	((bool,tempDependentFluidBeta,false,,"If true, fluid volumetric thermal expansion coefficient, :yref:`ThermalEngine::fluidBeta`, is temperature dependent (linear model between 20-70 degC)"))
+        	((Real,minimumFluidCondDist,0,,"Useful for maintaining stability despite poor external triangulations involving flat tetrahedrals. Consider setting to minimum particle diameter to keep scale."))
 		,
 		/* extra initializers */
 		,
@@ -149,13 +149,10 @@ class ThermalEngine : public PartialEngine
 	)
 	// clang-format on
 	DECLARE_LOGGER;
-
-	
 };
 REGISTER_SERIALIZABLE(ThermalEngine);
 
 } // namespace yade
 
-#endif//THERMAL
-#endif//YADE_OPENMP
-
+#endif //THERMAL
+#endif //YADE_OPENMP
