@@ -1,3 +1,4 @@
+#include <lib/high-precision/Constants.hpp>
 #include <py/_utils.hpp>
 // https://codeyarns.com/2014/03/11/how-to-selectively-ignore-a-gcc-warning/
 #pragma GCC diagnostic push
@@ -12,11 +13,14 @@ CREATE_CPP_LOCAL_LOGGER("_utils.cpp");
 
 namespace yade { // Cannot have #include directive inside.
 
+using math::max;
+using math::min; // using inside .cpp file is ok.
+
 py::tuple negPosExtremeIds(int axis, Real distFactor)
 {
-	py::tuple extrema  = Shop::aabbExtrema();
-	Real      minCoord = py::extract<double>(extrema[0][axis])(), maxCoord = py::extract<double>(extrema[1][axis])();
-	py::list  minIds, maxIds;
+	const auto extrema  = Shop::aabbExtrema();
+	Real       minCoord = extrema.first[axis], maxCoord = extrema.second[axis];
+	py::list   minIds, maxIds;
 	for (const auto& b : *Omega::instance().getScene()->bodies) {
 		shared_ptr<Sphere> s = YADE_PTR_DYN_CAST<Sphere>(b->shape);
 		if (!s)
@@ -99,7 +103,7 @@ py::tuple interactionAnglesHistogram(int axis, int mask, size_t bins, py::tuple
 		Real theta = acos(n[axis2] / nLen) * (n[axis3] > 0 ? 1 : -1);
 		if (theta < 0)
 			theta += Mathr::PI;
-		int binNo = int(std::round(theta / binStep));
+		int binNo = int(math::round(theta / binStep));
 		cummProj[binNo] += nLen;
 	}
 	py::list val, binMid;
@@ -305,7 +309,7 @@ void wireNoSpheres() { wireSome("noSpheres"); }
  */
 bool pointInsidePolygon(py::tuple xy, py::object vertices)
 {
-	Real           testx = py::extract<double>(xy[0])(), testy = py::extract<double>(xy[1])();
+	Real           testx = py::extract<Real>(xy[0])(), testy = py::extract<Real>(xy[1])();
 	char**         vertData;
 	int            rows, cols;
 	PyArrayObject* vert   = (PyArrayObject*)vertices.ptr();
@@ -426,6 +430,12 @@ shared_ptr<Interaction> Shop__createExplicitInteraction(Body::id_t id1, Body::id
 }
 
 Real      Shop__unbalancedForce(bool useMaxForce /*false by default*/) { return Shop::unbalancedForce(useMaxForce); }
+py::tuple Shop__aabbExtrema(Real cutoff, bool centers)
+{
+	const auto aabb = Shop::aabbExtrema(cutoff, centers);
+	return py::make_tuple(aabb.first, aabb.second);
+}
+
 py::tuple Shop__totalForceInVolume()
 {
 	Real     stiff;
@@ -652,7 +662,7 @@ try {
 	        "resolution=1600 require a 64 bit operating system, because more than 4GB of RAM is used, a resolution=800 will use 500MB of RAM.\n:param "
 	        "Vector3 start: start corner of the volume.\n:param Vector3 end: end corner of the volume.\n");
 	py::def("aabbExtrema",
-	        Shop::aabbExtrema,
+	        Shop__aabbExtrema,
 	        (py::arg("cutoff") = 0.0, py::arg("centers") = false),
 	        "Return coordinates of box enclosing all spherical bodies\n\n:param bool centers: do not take sphere radii in account, only their "
 	        "centroids\n:param float∈〈0…1〉 cutoff: relative dimension by which the box will be cut away at its boundaries.\n\n\n:return: [lower corner, "
@@ -755,10 +765,11 @@ try {
 	py::def("flipCell",
 	        &Shop::flipCell,
 	        (py::arg("flip") = Matrix3r(Matrix3r::Zero())),
-	        "Flip periodic cell so that angles between $R^3$ axes and transformed axes are as small as possible. This function relies on the fact that "
-	        "periodic cell defines by repetition or its corners regular grid of points in $R^3$; however, all cells generating identical grid are "
-	        "equivalent and can be flipped one over another. This necessiatates adjustment of :yref:`Interaction.cellDist` for interactions that cross "
-	        "boundary and didn't before (or vice versa), and re-initialization of collider. The *flip* argument can be used to specify desired flip: "
+	        "Flip periodic cell so that angles between $R^3$ axes and transformed axes are as small as possible, using the two following facts:"
+	        "1. repeating in $R^3$ space the corners of a periodic cell defines a regular grid; 2. two cells leading through this process to a unique grid "
+	        "are "
+	        "equivalent and can be flipped one over another. Flipping necessitates adjustment of :yref:`Interaction.cellDist` for interactions that cross "
+	        "the boundary and didn't before (or vice versa), and re-initialization of collider. The *flip* argument can be used to specify desired flip: "
 	        "integers, each column for one axis; if zero matrix, best fit (minimizing the angles) is computed automatically.\n\nIn c++, this function is "
 	        "accessible as ``Shop::flipCell``.");
 	py::def("getViscoelasticFromSpheresInteraction",
@@ -970,4 +981,3 @@ try {
 	boost::python::handle_exception();
 	throw;
 }
-
