@@ -2,6 +2,7 @@
 
 #include <lib/base/AliasNamespaces.hpp>
 #include <lib/base/Logging.hpp>
+#include <lib/high-precision/Constants.hpp>
 #include <lib/pyutil/doc_opts.hpp>
 #include <lib/pyutil/gil.hpp>
 #include <lib/pyutil/raw_constructor.hpp>
@@ -43,6 +44,9 @@ CREATE_CPP_LOCAL_LOGGER("yadeWrapper.cpp");
 
 namespace yade { // Cannot have #include directive inside.
 
+using math::max;
+using math::min; // using inside .cpp file is ok.
+
 /*
 Python normally iterates over object it is has __getitem__ and __len__, which BodyContainer does.
 However, it will not skip removed bodies automatically, hence this iterator which does just that.
@@ -134,8 +138,8 @@ public:
 	Body::id_t         insertAtId(shared_ptr<Body> b, Body::id_t pos) { return proxee->insertAtId(b, pos); }
 	vector<Body::id_t> appendList(vector<shared_ptr<Body>> bb)
 	{
-		boost::mutex::scoped_lock lock(Omega::instance().renderMutex);
-		vector<Body::id_t>        ret;
+		const std::lock_guard<std::mutex> lock(Omega::instance().renderMutex);
+		vector<Body::id_t>                ret;
 		FOREACH(shared_ptr<Body> & b, bb) { ret.push_back(append(b)); }
 		return ret;
 	}
@@ -392,7 +396,7 @@ public:
 			}
 
 			//get pointer lists of spheres, that should be replaced:
-			int                      numReplaceTmp = int(std::round(num * amounts[ii]));
+			int                      numReplaceTmp = int(math::round(num * amounts[ii]));
 			vector<shared_ptr<Body>> bpListTmp(numReplaceTmp);
 			int                      a = 0, c = 0; //counters
 			vector<int>              posTmp;
@@ -445,7 +449,7 @@ public:
 
 					shared_ptr<Sphere> sphereTmp = shared_ptr<Sphere>(new Sphere());
 					sphereTmp->radius            = newRadTmp[jj];
-					sphereTmp->color             = Vector3r(Mathr::UnitRandom(), Mathr::UnitRandom(), Mathr::UnitRandom());
+					sphereTmp->color             = Vector3r(math::unitRandom(), math::unitRandom(), math::unitRandom());
 					sphereTmp->color.normalize();
 					newSphere->shape = sphereTmp;
 
@@ -1063,7 +1067,12 @@ public:
 		OMEGA.simulationLoop->workerThrew = false;
 		throw OMEGA.simulationLoop->workerException;
 	}
-	bool       isRunning() { return OMEGA.isRunning(); }
+	bool isRunning() { return OMEGA.isRunning(); }
+	void throwIfRunning()
+	{
+		if (isRunning())
+			throw std::runtime_error("Please call O.stop() first.");
+	}
 	py::object get_filename()
 	{
 		string f = OMEGA.sceneFile;
@@ -1142,7 +1151,11 @@ public:
 		OMEGA.getScene()->time = 0;
 		OMEGA.timeInit();
 	}
-	void switchScene() { std::swap(OMEGA.scenes[OMEGA.currentSceneNb], OMEGA.sceneAnother); }
+	void switchScene()
+	{
+		throwIfRunning();
+		std::swap(OMEGA.scenes[OMEGA.currentSceneNb], OMEGA.sceneAnother);
+	}
 	void resetAllScenes()
 	{
 		Py_BEGIN_ALLOW_THREADS;
@@ -1151,8 +1164,12 @@ public:
 		OMEGA.resetAllScenes();
 		OMEGA.createSimulationLoop();
 	}
-	void switchToScene(int i) { OMEGA.switchToScene(i); }
-	int  addScene() { return OMEGA.addScene(); }
+	void switchToScene(int i)
+	{
+		throwIfRunning();
+		OMEGA.switchToScene(i);
+	}
+	int addScene() { return OMEGA.addScene(); }
 
 	// Scene manipulation in multithread situations as python object or as a string (e.g. FEMxDEM, MPI, ...)
 	shared_ptr<Scene> scene_get() { return OMEGA.getScene(); }
@@ -1171,7 +1188,7 @@ public:
 	PyObject* sceneToString()
 	{
 #endif
-		ostringstream oss;
+		std::ostringstream oss;
 	yade::ObjectIO::save<decltype(OMEGA.getScene()), boost::archive::binary_oarchive>(oss, "scene", OMEGA.getScene());
 	oss.flush();
 #if PY_MAJOR_VERSION < 3
@@ -1288,7 +1305,7 @@ pyMaterialContainer materials_get(void) { return pyMaterialContainer(OMEGA.getSc
 py::list listChildClassesNonrecursive(const string& base)
 {
 	py::list ret;
-	for (map<string, DynlibDescriptor>::const_iterator di = Omega::instance().getDynlibsDescriptor().begin();
+	for (std::map<std::string, DynlibDescriptor>::const_iterator di = Omega::instance().getDynlibsDescriptor().begin();
 	     di != Omega::instance().getDynlibsDescriptor().end();
 	     ++di)
 		if (Omega::instance().isInheritingFrom((*di).first, base))
@@ -1300,9 +1317,9 @@ bool isChildClassOf(const string& child, const string& base) { return (Omega::in
 
 py::list plugins_get()
 {
-	const map<string, DynlibDescriptor>& plugins = Omega::instance().getDynlibsDescriptor();
-	std::pair<string, DynlibDescriptor>  p;
-	py::list                             ret;
+	const std::map<std::string, DynlibDescriptor>& plugins = Omega::instance().getDynlibsDescriptor();
+	std::pair<string, DynlibDescriptor>            p;
+	py::list                                       ret;
 	for (const auto& p : plugins)
 		ret.append(p.first);
 	return ret;
@@ -1410,15 +1427,17 @@ public:
 	{
 		TRACE;
 		gilLock lock;
+#if PY_MAJOR_VERSION >= 3
 		LOG_TRACE("GIL State: " << PyGILState_Check());
-		return get_override("contactForce")(u, a);
+#endif
+		return static_cast<Real>(get_override("contactForce")(u, a));
 	}
 
 	virtual Real potentialForce(Real const& u, Real const& a) const
 	{
 		TRACE;
 		gilLock lock;
-		return get_override("potentialForce")(u, a);
+		return static_cast<Real>(get_override("potentialForce")(u, a));
 	}
 
 	virtual bool hasContact(Real const& u, Real const& a) const
@@ -1701,11 +1720,13 @@ try {
 	                &pyBodyContainer::getUseRedirection,
 	                &pyBodyContainer::setUseRedirection,
 	                "true if the scene uses up-to-date lists for boundedBodies and realBodies; turned true automatically 1/ after removal of bodies if "
-	                ":yref:`enableRedirection`=True, and 2/ in MPI execution.")
+	                ":yref:`enableRedirection=True <BodyContainer.enableRedirection>`, and 2/ in MPI execution. |yupdate|")
 	        .add_property(
 	                "enableRedirection",
 	                &pyBodyContainer::getEnableRedirection,
 	                &pyBodyContainer::setEnableRedirection,
+	                // FIXME: the same docstring is in two places. But only one is used in docs, py/wrapper/yadeWrapper.cpp and core/BodyContainer.hpp
+	                // see https://gitlab.com/yade-dev/trunk/-/issues/173
 	                "let collider switch to optimized algorithm with body redirection when bodies are erased - true by default");
 	py::class_<pyBodyIterator>("BodyIterator", py::init<pyBodyIterator&>())
 	        .def("__iter__", &pyBodyIterator::pyIter)
@@ -1747,7 +1768,8 @@ try {
 	        .def("f",
 	             &pyForceContainer::force_get,
 	             (py::arg("id"), py::arg("sync") = false),
-	             "Force applied on body. For clumps in openMP, synchronize the force container with sync=True, else the value will be wrong.")
+	             "Resultant force on body, excluding :yref:`gravity<NewtonIntegrator.gravity>`. For clumps in openMP, synchronize the force container with "
+	             "sync=True, else the value will be wrong.")
 	        .def("t",
 	             &pyForceContainer::torque_get,
 	             (py::arg("id"), py::arg("sync") = false),
@@ -1782,7 +1804,7 @@ try {
 	py::class_<pyMaterialContainer>(
 	        "MaterialContainer",
 	        "Container for :yref:`Materials<Material>`. A material can be accessed using \n\n #. numerical index in range(0,len(cont)), like cont[2]; \n "
-	        "#. textual label that was given to the material, like cont['steel']. This etails traversing all materials and should not be used frequently.",
+	        "#. textual label that was given to the material, like cont['steel']. This entails traversing all materials and should not be used frequently.",
 	        py::init<pyMaterialContainer&>())
 	        .def("append", &pyMaterialContainer::append, "Add new shared :yref:`Material`; changes its id and return it.")
 	        .def("append", &pyMaterialContainer::appendList, "Append list of :yref:`Material` instances, return list of ids.")
