@@ -7,7 +7,7 @@ from builtins import object
 from yade.wrapper import *
 from yade import utils
 
-from minieigen import *
+from yade.minieigenHP import *
 
 
 def textExt(fileName,format='x_y_z_r',shift=Vector3.Zero,scale=1.0,attrs=[],**kw):
@@ -17,7 +17,7 @@ def textExt(fileName,format='x_y_z_r',shift=Vector3.Zero,scale=1.0,attrs=[],**kw
 	:param str format: the name of output format. Supported `x_y_z_r`(default), `x_y_z_r_matId`, 'x_y_z_r_attrs'
 	:param [float,float,float] shift: [X,Y,Z] parameter moves the specimen.
 	:param float scale: factor scales the given data.
-	:param list attrs: attrs read from file if export.textExt(format='x_y_z_r_attrs') were used ('passed by refernece' style)
+	:param list attrs: attrs read from file if export.textExt(format='x_y_z_r_attrs') were used ('passed by reference' style)
 	:param \*\*kw: (unused keyword arguments) is passed to :yref:`yade.utils.sphere`
 	:returns: list of spheres.
 
@@ -56,6 +56,50 @@ def textExt(fileName,format='x_y_z_r',shift=Vector3.Zero,scale=1.0,attrs=[],**kw
 	return ret
 
 
+def textFacets(fileName,format='x1_y1_z1_x2_y2_z2_x3_y3_z3',shift=Vector3.Zero,scale=1.0,**kw):
+	"""Load facet coordinates from file in specific format, returns a list of corresponding bodies; that may be inserted to the simulation with O.bodies.append().
+	
+	:param str filename: file name
+	:param str format: the name of output format. Supported `x1_y1_z1_x2_y2_z2_x3_y3_z3`(default), `x1_y1_z1_x2_y2_z2_x3_y3_z3_matId`, 'id_x1_y1_z1_x2_y2_z2_x3_y3_z3_matId' or 'x1_y1_z1_x2_y2_z2_x3_y3_z3_attrs'
+	:param [float,float,float] shift: [X,Y,Z] parameter moves the specimen.
+	:param float scale: factor scales the given data.
+	:param \*\*kw: (unused keyword arguments) is passed to :yref:`yade.utils.facet`
+	:returns: list of facets.
+
+	Lines starting with # are skipped
+	"""
+	infile = open(fileName,"r")
+	lines = infile.readlines()
+	infile.close()
+	ret=[]
+	for line in lines:
+		data = line.split()
+		if (data[0] == "#format"):
+			format=data[1]
+			continue
+		elif (data[0][0] == "#"): continue
+		
+		if (format=='x1_y1_z1_x2_y2_z2_x3_y3_z3'):
+			V1=Vector3( float(data[0]),float(data[1]),float(data[2]));	V2=Vector3( float(data[3]),float(data[4]),float(data[5]));	V3=Vector3( float(data[6]),float(data[7]),float(data[8]))
+			ret.append(utils.facet((shift+V1*scale, shift+V2*scale, shift+V3*scale),**kw))
+		
+		elif (format=='x1_y1_z1_x2_y2_z2_x3_y3_z3_matId'):
+			V1=Vector3( float(data[0]),float(data[1]),float(data[2]));	V2=Vector3( float(data[3]),float(data[4]),float(data[5]));	V3=Vector3( float(data[6]),float(data[7]),float(data[8]))
+			ret.append(utils.facet((shift+V1*scale, shift+V2*scale, shift+V3*scale),material=int(data[9]),**kw))
+		
+		elif (format=='id_x1_y1_z1_x2_y2_z2_x3_y3_z3_matId'):
+			V1=Vector3( float(data[1]),float(data[2]),float(data[3]));	V2=Vector3( float(data[4]),float(data[5]),float(data[6]));	V3=Vector3( float(data[7]),float(data[8]),float(data[9]))
+			ret.append(utils.facet((shift+V1*scale, shift+V2*scale, shift+V3*scale),material=int(data[10]),**kw))
+		
+		elif (format=='x1_y1_z1_x2_y2_z2_x3_y3_z3_attrs'):
+			V1=Vector3( float(data[0]),float(data[1]),float(data[2]));	V2=Vector3( float(data[3]),float(data[4]),float(data[5]));	V3=Vector3( float(data[6]),float(data[7]),float(data[8]))
+			ret.append(utils.facet((shift+V1*scale, shift+V2*scale, shift+V3*scale),**kw))
+			attrs.append(data[4:])
+			
+		else:
+			raise RuntimeError("Please, specify a correct format output!");
+	return ret
+
 def textClumps(fileName,shift=Vector3.Zero,discretization=0,orientation=Quaternion((0,1,0),0.0),scale=1.0,**kw):
 	"""Load clumps-members from file, insert them to the simulation.
 	
@@ -114,15 +158,16 @@ def text(fileName,shift=Vector3.Zero,scale=1.0,**kw):
 	return textExt(fileName=fileName,format='x_y_z_r',shift=shift,scale=scale,**kw)
 
 
-def stl(file, dynamic=None,fixed=True,wire=True,color=None,highlight=False,noBound=False,material=-1):
+def stl(file, dynamic=None,fixed=True,wire=True,color=None,highlight=False,noBound=False,material=-1,scale=1.0,shift=Vector3.Zero):
 	""" Import geometry from stl file, return list of created facets."""
 	imp = STLImporter()
 	facets=imp.ymport(file)
 	for b in facets:
+		b.shape.setVertices(b.shape.vertices[0]*scale, b.shape.vertices[1]*scale, b.shape.vertices[2]*scale)
 		b.shape.color=color if color else utils.randomColor()
 		b.shape.wire=wire
 		b.shape.highlight=highlight
-		pos=b.state.pos
+		pos=b.state.pos*scale+shift
 		utils._commonBodySetup(b,0,Vector3(0,0,0),material=material,pos=pos,noBound=noBound,dynamic=dynamic,fixed=fixed)
 		b.aspherical=False
 	return facets
@@ -457,10 +502,9 @@ def ele(nodeFileName,eleFileName,shift=(0,0,0),scale=1.0,**kw):
 	return tetras
 
 def textPolyhedra(fileName,material,shift=Vector3.Zero,scale=1.0,orientation=Quaternion((0,1,0),0.0),**kw):
-	from yade import polyhedra_utils
 	"""Load polyhedra from a text file.
 	
-	:param str filename: file name
+	:param str filename: file name. Expected file format is the one output by export.textPolyhedra.
 	:param [float,float,float] shift: [X,Y,Z] parameter moves the specimen.
 	:param float scale: factor scales the given data.
 	:param quaternion orientation:  orientation of the imported polyhedra
@@ -469,6 +513,7 @@ def textPolyhedra(fileName,material,shift=Vector3.Zero,scale=1.0,orientation=Qua
 
 	Lines starting with # are skipped
 	"""
+	from yade import polyhedra_utils
 	infile = open(fileName,"r")
 	lines = infile.readlines()
 	infile.close()
@@ -484,7 +529,7 @@ def textPolyhedra(fileName,material,shift=Vector3.Zero,scale=1.0,orientation=Qua
 			raise RuntimeError("Check polyhedra input file! Number of parameters in the first line is not 3!");
 		else:
 			vertLoad = []
-			ids = int(data[0])
+#			ids = int(data[0])
 			verts = int(data[1])
 			surfs = int(data[2])
 			i+=1
