@@ -2,12 +2,16 @@
 
 # First upload of the packages
 
+PATHDEB="/home/anton/deb/"
+
 set -e
 
-for i in bionic buster stretch xenial bullseye
+NEW_ID=$(curl -L "https://gitlab.com/api/v4/projects/10133144/repository/commits/master" | jq --raw-output '.short_id')
+echo $NEW_ID > ${PATHDEB}/OLD_ID
+
+for i in bionic buster stretch xenial bullseye focal
 do
-    cd /root/deb
-#wget https://gitlab.com/api/v4/projects/10133144/jobs/artifacts/feature%2Fdailypackages/download?job=deb_$i -O yade.zip
+    cd ${PATHDEB}
     wget https://gitlab.com/api/v4/projects/10133144/jobs/artifacts/master/download?job=deb_$i -O yade.zip
     unzip yade.zip
     aptly repo remove yadedaily-$i 'yadedaily'
@@ -16,6 +20,6 @@ do
     aptly repo remove yadedaily-$i 'python3-yadedaily'
     aptly repo add yadedaily-$i deb/*.deb
     aptly repo add yadedaily-$i deb/*.dsc
-    rm -rf /root/deb/*
-    aptly publish repo yadedaily-$i s3:yadedaily-repo:/debian/
+    rm -rf ${PATHDEB}/*
+    aptly publish repo yadedaily-$i filesystem:yadedaily:
 done
